@@ -34,7 +34,6 @@ static	char	CTCP_Reply_Buffer[BIG_BUFFER_SIZE + 1] = "";
 
 static	void	do_new_notice_ctcp();
 
-extern	int	IgnoreCombo();
 extern	void	strmcat();
 
 /* forward declarations for the built in CTCP functions */
@@ -410,15 +409,9 @@ char	*from,
 		*args,
 		*ptr;
 	char	*arg_copy = NULL;
-	int	flag,
-		flag2;
+	int	flag;
 
-	flag = is_ignored(from, IGNORE_CTCPS);
-	if (FromUserHost)
-	{
-		flag2 = is_ignored(FromUserHost, IGNORE_CTCPS);
-		flag = IgnoreCombo(flag, flag2);
-	}
+	flag = double_ignore(from, FromUserHost, IGNORE_CTCPS);
 
 	if (!in_ctcp_flag)
 		in_ctcp_flag = 1;
@@ -447,28 +440,27 @@ char	*from,
 				args = empty_string;
 			malloc_strcpy(&arg_copy, args);
 			if (!ctcp_dropped)
-				for (i = 0; i < NUMBER_OF_CTCPS; i++)
+			    for (i = 0; i < NUMBER_OF_CTCPS; i++)
+			    {
+				if (strcmp(cmd, ctcp_cmd[i].name) == 0)
 				{
-					if (strcmp(cmd, ctcp_cmd[i].name) == 0)
-					{
 		/*
 		 * This test here to stop irc operators seeing ctcp replies
 		 * when using global messages - phone, dec, 1992.
 		 */
-						if (*to != '$' && !(*to == '#'
-						  && !lookup_channel(to,
-						  from_server, 0)) && (ptr =
-						  ctcp_cmd[i].func(&(ctcp_cmd[i]),
-						  from, to, arg_copy)))
-						{
-							strcat(ctcp_buffer,ptr);
-							new_free(&ptr);
-						}
-						ctcp_flag = ctcp_cmd[i].flag;
-						cmd = ctcp_cmd[i].name;
-						break;
-					}
+				    if (*to != '$' && !(*to == '#' &&
+				      !lookup_channel(to, from_server, 0)) &&
+				      (ptr = ctcp_cmd[i].func(&(ctcp_cmd[i]),
+				      from, to, arg_copy)))
+				    {
+				    	strcat(ctcp_buffer, ptr);
+				    	new_free(&ptr);
+				    }
+				    ctcp_flag = ctcp_cmd[i].flag;
+				    cmd = ctcp_cmd[i].name;
+				    break;
 				}
+			    }
 			new_free(&arg_copy);
 			if (!ctcp_dropped && in_ctcp_flag == 1 &&
 			    do_hook(CTCP_LIST, "%s %s %s %s", from, to, cmd,
@@ -596,7 +588,10 @@ char	*from,
 					currenttime;
 
 				currenttime = time(NULL);
-				timediff = currenttime-(Long)atoi(args);
+				if (args && *args)
+					timediff = currenttime-(Long)atoi(args);
+				else
+					timediff = (Long) 0;
 				sprintf(buf, "%d second%s", timediff,
 					(timediff == 1) ? "" : "s");
 				args = buf;
