@@ -10,7 +10,7 @@
 
 #include <stdio.h>
 #include <signal.h>
-#if defined (XD88) || defined (POSIX) && !defined(_IBMR2)
+#if (defined (XD88) || defined (POSIX) || defined(UNICOS)) && !defined(_IBMR2)
 # include <sys/fcntl.h>
 #endif
 #if defined(linux) || defined (SOLARIS)
@@ -31,14 +31,15 @@
 #endif /* defined(_AUX_SOURCE) || defined(_IBMR2) || defined (ESIX) || defined (POSIX) */
 #ifdef SOLARIS
 # include <sys/socket.h>
-# include <netinet/in.h>
-# include <arpa/inet.h>
 #endif
 #include <sys/stat.h>
 #include <sys/file.h>
 #include <sys/time.h>
+/*			these included in dcc.c and 386BSD has allows them to be
+			included twice.
 #include <netinet/in.h>
 #include <arpa/inet.h>
+*/
 #include <ctype.h>
 #include <netdb.h>
 #include "irc.h"
@@ -54,6 +55,10 @@
 #include "window.h"
 #include "output.h"
 
+#if defined(ultrix) || defined(HPUX)
+# define BROKEN_DCC_TIMES
+#endif /* ultrix || HPUX */
+
 extern	int	dgets();
 
 extern	void	dcc_chat();
@@ -141,12 +146,7 @@ int	type,
 	NewClient->starttime = 0;
 	malloc_strcpy(&(NewClient->description), name);
 	malloc_strcpy(&(NewClient->user), user);
-/* #if defined(ultrix) && !defined(__GNUC__)
-	time(&(time_t)NewClient->lasttime);
-#else */	/* Nap said it wasn't needed */
- 
 	time(&NewClient->lasttime);
-/* #endif */
 	return NewClient;
 }
 
@@ -269,9 +269,11 @@ DCC_list	*Client;
 {
 	char    *user,
 		*Type;
-	struct	sockaddr_in	localaddr;
+	struct	sockaddr_in	localaddr,
+		remaddr;
 	unsigned Long	myip;
-	int	sla;
+	int	sla,
+		rl = sizeof(remaddr);
 
 	user = Client->user;
 	myip = ntohl(MyHostAddr.s_addr);
@@ -291,9 +293,11 @@ DCC_list	*Client;
 		Client->flags &= ~DCC_OFFER;
 		Client->flags |= DCC_ACTIVE;
 		message_from(null(char *), LOG_DCC);
+		(void) getpeername(Client->read, (struct sockaddr *) &remaddr,
+			&rl);
 		if ((Client->flags & DCC_TYPES) != DCC_RAW)
-			say("DCC %s connection with %s established",
-					Type, user);
+			say("DCC %s connection with %s[%s] established",
+				Type, user, inet_ntoa(remaddr.sin_addr));
 		message_from(null(char *), LOG_CRAP);
 		Client->starttime = time(NULL);
 		Client->bytes_read = Client->bytes_sent = 0L;
@@ -976,7 +980,8 @@ DCC_list	*Client;
 		Client->read = Client->write;
 		Client->flags &= ~DCC_WAIT;
 		Client->flags |= DCC_ACTIVE;
-		say("DCC chat connection to %s established", Client->user);
+		say("DCC chat connection to %s[%s] established", Client->user,
+			inet_ntoa(remaddr.sin_addr));
 		Client->starttime = time(NULL);
 		return;
 	}
@@ -1116,7 +1121,8 @@ DCC_list	*Client;
 		read(Client->read, Client->talkchars, 3);
 #endif
 		Client->bytes_read = Client->bytes_sent = 3;
-		say("TALK connection to %s established", Client->user);
+		say("TALK connection to %s[%s] established", Client->user,
+			inet_ntoa(remaddr.sin_addr));
 		return;
 	}
 	switch(bytesread = dgets(tmp, -BIG_BUFFER_SIZE, Client->read,
@@ -1165,7 +1171,8 @@ DCC_list	*Client;
 		Client->flags |= DCC_ACTIVE;
 		Client->bytes_sent = 0L;
 		Client->starttime = time(NULL);
-		say("DCC SEND connection to %s established", Client->user);
+		say("DCC SEND connection to %s[%s] established", Client->user,
+			inet_ntoa(remaddr.sin_addr));
 		if ((Client->file = open(Client->description, O_RDONLY)) == -1)
 		{
 			say("Unable to open %s: %s\n", Client->description,
@@ -1221,9 +1228,9 @@ DCC_list	*Client;
 		 * sometime....  -phone jan, 1993.
 		 */
 
-#if 0
+#ifdef BROKEN_DCC_TIMES
 		char	lame_ultrix[10];	/* should be plenty */
-#endif
+#endif /* BROKEN_DCC_TIMES */
 		Long	xtime = time(NULL) - Client->starttime;
 		double	sent = (double)Client->bytes_sent;
 
@@ -1232,13 +1239,16 @@ DCC_list	*Client;
 		sent /= (double)1024.0;
 		if (xtime <= 0)
 			xtime = 1;
-#if 0
+#ifdef BROKEN_DCC_TIMES
 		sprintf(lame_ultrix, "%2.4g", (sent / (double)xtime));
-#endif 
+		say("DCC SEND:%s to %s completed %s kb/sec",
+			Client->description, Client->user, lame_ultrix);
+#else /* BROKEN_DCC_TIMES */
 		say("DCC SEND:%s to %s completed %2.4g kb/sec",
 			Client->description, Client->user, (sent / (double) xtime));
+#endif  /* BROKEN_DCC_TIMES */
 		close(Client->read);
-		Client->read = Client->write = (-1);
+		Client->read = Client->write = -1;
 		Client->flags |= DCC_DELETE;
 		close(Client->file);
 		return;
@@ -1267,9 +1277,9 @@ DCC_list	*Client;
 		 * sometime....  -phone jan, 1993.
 		 */
 
-#if 0
+#ifdef BROKEN_DCC_TIMES
 		char    lame_ultrix[10];        /* should be plenty */
-#endif
+#endif /* BROKEN_DCC_TIMES */
 		Long	xtime = time(NULL) - Client->starttime;
 		double	sent = (double)Client->bytes_read;
 
@@ -1278,11 +1288,14 @@ DCC_list	*Client;
 		sent /= (double)1024.0;
 		if (xtime <= 0)
 			xtime = 1;
-#if 0
+#ifdef BROKEN_DCC_TIMES
 		sprintf(lame_ultrix, "%2.4g", (sent / (double)xtime));
-#endif
+		say("DCC GET:%s from %s completed %s kb/sec",
+			Client->description, Client->user, lame_ultrix);
+#else /* BROKEN_DCC_TIMES */
 		say("DCC GET:%s from %s completed %2.4g kb/sec",
 			Client->description, Client->user, (sent / (double) xtime));
+#endif /* BROKEN_DCC_TIMES */
 		close(Client->read);
 		close(Client->file);
 		Client->read = Client->write = (-1);
