@@ -66,11 +66,11 @@ TimerList *PendingTimers = null(TimerList *);
 #define MAX_LOAD_DEPTH 10
 
 /* recv_nick: the nickname of the last person to send you a privmsg */
-char	*recv_nick = null(char *);
+char	*recv_nick = NULL;
 
 /* sent_nick: the nickname of the last person to whom you sent a privmsg */
-char	*sent_nick = null(char *);
-char	*sent_body = null(char *);
+char	*sent_nick = NULL;
+char	*sent_body = NULL;
 
 /* Used to keep down the nesting of /LOADs and to determine if we
  * should activate the warning for /ONs if the NOVICE variable is set.
@@ -104,8 +104,8 @@ static	void	cd();
 extern	void	edit_char();
 extern	void	foreach();
 extern	void	whilecmd();
-static	void	quit();
-static	void	wall();
+static	void	e_quit();
+static	void	e_wall();
 static	void	send_2comm();
 static	void	send_comm();
 static	void	send_topic();
@@ -113,13 +113,13 @@ static	void	send_kick();
 static	void	send_channel_com();
 static	void	clear();
 static	void	quote();
-static	void	privmsg();
+static	void	e_privmsg();
 static	void	flush();
 extern	void	server();
 static	void	away();
 extern	void	query();
 static	void	oper();
-static	void	channel();
+static	void	e_channel();
 extern	void	execcmd();
 extern	void	ignore();
 static	void	who();
@@ -127,7 +127,7 @@ static	void	whois();
 static	void	ison();
 static	void	userhost();
 static	void	info();
-static	void	nick();
+static	void	e_nick();
 static	void	comment();
 extern	void	bindcmd();
 extern	void	parsekeycmd();
@@ -209,9 +209,9 @@ static	IrcCommand irc_command[NUMBER_OF_COMMANDS * 2] =
 	{ "ASSIGN",	"1",		alias,			0 },
 	{ "AWAY",	"AWAY",		away,			0 },
 	{ "BIND",	NULL,		bindcmd,		0 },
-	{ "BYE",	"QUIT",		quit,			NONOVICEABBREV},
+	{ "BYE",	"QUIT",		e_quit,			NONOVICEABBREV},
 	{ "CD",		NULL,		cd,			0 },
-	{ "CHANNEL",	"JOIN",		channel,		0 },
+	{ "CHANNEL",	"JOIN",		e_channel,		0 },
 	{ "CLEAR",	NULL,		clear,			0 },
 	{ "COMMENT",	NULL,		comment,		0 },
 	{ "CONNECT",	"CONNECT",	send_comm,		0 },
@@ -227,7 +227,7 @@ static	IrcCommand irc_command[NUMBER_OF_COMMANDS * 2] =
 	{ "ENCRYPT",	NULL,		encrypt_cmd,		0 },
 	{ "EVAL",	NULL,		evalcmd,		0 },
 	{ "EXEC",	NULL,		execcmd,		0 },
-	{ "EXIT",	"QUIT",		quit,			NONOVICEABBREV},
+	{ "EXIT",	"QUIT",		e_quit,			NONOVICEABBREV},
 	{ "FLUSH",	NULL,		flush,			0 },
 	{ "FOREACH",	NULL,		foreach,		0 },
 	{ "HASH",	"HASH",		send_comm,		0 },
@@ -241,7 +241,7 @@ static	IrcCommand irc_command[NUMBER_OF_COMMANDS * 2] =
 	{ "INPUT",	NULL,		inputcmd,		0 },
 	{ "INVITE",	"INVITE",	send_comm,		0 },
 	{ "ISON",	"ISON",		ison,			0 },
-	{ "JOIN",	"JOIN",		channel,		0 },
+	{ "JOIN",	"JOIN",		e_channel,		0 },
 	{ "KICK",	"KICK",		send_kick,		0 },
 	{ "KILL",	"KILL",		send_2comm,		0 },
 	{ "LASTLOG",	NULL,		lastlog,		0 },
@@ -255,11 +255,11 @@ static	IrcCommand irc_command[NUMBER_OF_COMMANDS * 2] =
 	{ "MLOAD",	NULL,		mload,			0 },
 	{ "MODE",	"MODE",		send_channel_com,	0 },
 	{ "MOTD",	"MOTD",		send_comm,		0 },
-	{ "MSG",	"PRIVMSG",	privmsg,		0 },
+	{ "MSG",	"PRIVMSG",	e_privmsg,		0 },
 	{ "NAMES",	"NAMES",	funny_stuff,		0 },
-	{ "NICK",	"NICK",		nick,			0 },
+	{ "NICK",	"NICK",		e_nick,			0 },
 	{ "NOTE",	"NOTE",		send_comm,		0 },
-	{ "NOTICE",	"NOTICE",	privmsg,		0 },
+	{ "NOTICE",	"NOTICE",	e_privmsg,		0 },
 	{ "NOTIFY",	NULL,		notify,			0 },
 	{ "ON",		NULL,		on,			0 },
 	{ "OPER",	"OPER",		oper,			0 },
@@ -267,7 +267,7 @@ static	IrcCommand irc_command[NUMBER_OF_COMMANDS * 2] =
 	{ "PART",	"PART",		send_channel_com,	0 },
 	{ "PING",	NULL, 		pingcmd,		0 },
 	{ "QUERY",	NULL,		query,			0 },
-	{ "QUIT",	"QUIT",		quit,			NONOVICEABBREV},
+	{ "QUIT",	"QUIT",		e_quit,			NONOVICEABBREV},
 	{ "QUOTE",	NULL,		quote,			0 },
 	{ "REDIRECT",	NULL,		redirect,		0 },
 	{ "REHASH",	"REHASH",	send_comm,		0 },
@@ -279,7 +279,7 @@ static	IrcCommand irc_command[NUMBER_OF_COMMANDS * 2] =
 	{ "SENDLINE",	empty_string,	sendlinecmd,		0 },
 	{ "SERVER",	NULL,		server,			0 },
 	{ "SET",	NULL,		set_variable,		0 },
-	{ "SIGNOFF",	"QUIT",		quit,			NONOVICEABBREV},
+	{ "SIGNOFF",	"QUIT",		e_quit,			NONOVICEABBREV},
 	{ "SLEEP",	NULL,		sleepcmd,		0 },
 	{ "SQUIT",	"SQUIT",	send_2comm,		0 },
 	{ "STATS",	"STATS",	send_comm,		0 },
@@ -292,10 +292,10 @@ static	IrcCommand irc_command[NUMBER_OF_COMMANDS * 2] =
 	{ "USERHOST",	NULL,		userhost,		0 },
 	{ "USERS",	"USERS",	send_comm,		0 },
 	{ "VERSION",	"VERSION",	version,		0 },
-	{ "VOICE",	"VOICE",	privmsg,		0 },
+	{ "VOICE",	"VOICE",	e_privmsg,		0 },
 	{ "WAIT",	NULL,		waitcmd,		0 },
-	{ "WALL",	"WALL",		wall,			0 },
-	{ "WALLOPS",	"WALLOPS",	wall,			0 },
+	{ "WALL",	"WALL",		e_wall,			0 },
+	{ "WALLOPS",	"WALLOPS",	e_wall,			0 },
 	{ "WHICH",	"WHICH",	load,			0 },
 	{ "WHILE",	NULL,		whilecmd,		0 },
 	{ "WHO",	"WHO",		who,			0 },
@@ -303,9 +303,9 @@ static	IrcCommand irc_command[NUMBER_OF_COMMANDS * 2] =
 	{ "WHOWAS",	"WHOWAS",	whois,			0 },
 	{ "WINDOW",	NULL,		window,			0 },
 	{ "XECHO",	"XECHO",	echo,			0 },
-	{ "XTRA",	"XTRA",		privmsg,		0 },
+	{ "XTRA",	"XTRA",		e_privmsg,		0 },
 	{ "XTYPE",	NULL,		xtypecmd,		0 },
-	{ null(char *),	null(char *),	NULL,			0 }
+	{ NULL,		NULL,		NULL,			0 }
 };
 
 /*
@@ -405,22 +405,20 @@ char	*command,
 	if (to = next_arg(args, &args))
 	{
 		if (!strcmp(to, "*"))
-			if ((to=get_channel_by_refnum(0)) == null(char *))
+			if ((to=get_channel_by_refnum(0)) == NULL)
 				to = "0";
 		if (tag = next_arg(args, &args))
 			upper(tag);
 		else
 			tag = "VERSION";
 		if ((type = in_ctcp()) == -1)
-			echo(null(char *), "*** You may not use the CTCP \
-command in an ON CTCP_REPLY!");
+			echo(NULL, "*** You may not use the CTCP command in an ON CTCP_REPLY!");
 		else
 		{
 			if (args && *args)
 				send_ctcp(ctcp_type[type], to, tag, "%s", args);
 			else
-				send_ctcp(ctcp_type[type], to, tag,
-					null(char *));
+				send_ctcp(ctcp_type[type], to, tag, NULL);
 		}
 	}
 	else
@@ -509,7 +507,7 @@ char	*command,
 	}
 	set_funny_flags(min, max, flags);
 	if (strcmp(stuff, "*") == 0)
-		if ((stuff = get_channel_by_refnum(0)) == null(char *))
+		if (!(stuff = get_channel_by_refnum(0)))
 			stuff = empty_string;
 	if (index(stuff, '*'))
 	{
@@ -517,7 +515,7 @@ char	*command,
 		send_to_server("%s %s", command, empty_string);
 	}
 	else{
-		funny_match(null(char *));
+		funny_match(NULL);
 		send_to_server("%s %s", command, stuff);
 	}
 }
@@ -587,7 +585,7 @@ char	*command,
 		yell("WAIT has been called recursively.");
 
 	waiting = 1;
-	irc_io(null(char *), NULL, 0, 1);
+	irc_io(NULL, NULL, 0, 1);
 	waiting = 0;
 }
 
@@ -622,7 +620,7 @@ char	*command,
 	if (who = next_arg(args, &args))
 	{
 		if (!strcmp(who, "*"))
-			if ((who = get_channel_by_refnum(0)) == null(char *))
+			if (!(who = get_channel_by_refnum(0)))
 			{
 				say("Must be on a channel to redirect to '*'");
 				return;
@@ -633,7 +631,7 @@ char	*command,
 			return;
 		}
 		window_redirect(who, from_server);
-		parse_line(null(char *), args, null(char *), 0, 0);
+		parse_line(NULL, args, NULL, 0, 0);
 		send_to_server("%s", current_screen->redirect_token,
 			current_screen->screennum);
 	}
@@ -735,9 +733,9 @@ char	*command,
 	char	*nick;
 
 	oper_command = 1;
-	if ((nick = next_arg(args, &args)) == null(char *))
+	if (!(nick = next_arg(args, &args)))
 		nick = nickname;
-	if ((password = next_arg(args, &args)) == null(char *))
+	if (!(password = next_arg(args, &args)))
 	{
 		add_wait_prompt("Operator Password:",
 			oper_password_received, nick, WAIT_PROMPT_LINE);
@@ -789,7 +787,7 @@ char	*command,
 			return;
 		}
 #endif /* DAEMON_UID */
-		if ((ircrc_file = expand_twiddle(file)) == null(char *))
+		if (!(ircrc_file = expand_twiddle(file)))
 		{
 			say("Unknown user");
 			return;
@@ -806,10 +804,10 @@ char	*command,
 }
 
 /*
- * channel: does the channel command.  I just added displaying your current
+ * e_channel: does the channel command.  I just added displaying your current
  * channel if none is given 
  */
-static	void	channel(command, args)
+static	void	e_channel(command, args)
 char	*command,
 	*args;
 {
@@ -821,7 +819,7 @@ char	*command,
 		command = "JOIN";
 	else
 		command = "CHANNEL";
-	message_from(null(char *), LOG_CURRENT);
+	message_from(NULL, LOG_CURRENT);
 	if (chan = next_arg(args, &args))
 	{
 		if (get_int_var(NOVICE_VAR))
@@ -847,7 +845,7 @@ char	*command,
 					say("Wildcards not allowed here!");
 				else
 					add_to_whois_queue(chan, whois_join,
-						null(char *));
+						NULL);
 			}
 			else
 				say("You must specify a nickname!");
@@ -873,7 +871,7 @@ char	*command,
 	}
 	else
 		list_channels();
-	message_from(null(char *), LOG_CRAP);
+	message_from(NULL, LOG_CRAP);
 }
 
 /* comment: does the /COMMENT command, useful in .ircrc */
@@ -886,31 +884,28 @@ char	*command,
 }
 
 /*
- * nick: does the /NICK command.  Records the users current nickname and
+ * e_nick: does the /NICK command.  Records the users current nickname and
  * sends the command on to the server 
  */
 /*ARGSUSED*/
-static	void	nick(command, args)
+static	void	e_nick(command, args)
 char	*command,
 	*args;
 {
 	char	*nick;
 
-	if ((nick = next_arg(args, &args)) == null(char *))
+	if (!(nick = next_arg(args, &args)))
 	{
 		say("Your nickname is %s",
 			get_server_nickname(get_window_server(0)));
 		return;
 	}
-	if (check_nickname(nick))
+	if (nick = check_nickname(nick))
 	{
-		if (strcmp(nick, get_server_nickname(from_server)))
-		{
-			send_to_server("NICK %s", nick);
-			if (get_server_version(from_server) == Server2_5)
-				add_to_whois_queue(nick, whois_nickname,
-					null(char *));
-		}
+		send_to_server("NICK %s", nick);
+		if (get_server_version(from_server) == Server2_5)
+			add_to_whois_queue(nick, whois_nickname,
+				NULL);
 	}
 	else
 		say("Bad nickname");
@@ -927,7 +922,7 @@ char	*command,
 		send_to_server("%s %s", command, host);
 	else
 	{ 
-		say("Client: ircII %s", irc_version);
+		say("Client: ircII %s - %s", irc_version, internal_version);
 		send_to_server("%s", command);
 	}
 }
@@ -969,6 +964,7 @@ char	*command,
 	say("       \tMatthew Green         Christopher Williams");
 	say("       \tJonathan Lemon        Brian Koehmstedt");
 	say("       \tNicolas Pioch         Brian Fehdrau");
+	say("       \tDarren Reed");
 	send_to_server("%s %s", command, args);
 }
 
@@ -1031,17 +1027,17 @@ char	*args;
 			if (n >= 5)
 			{
 				add_to_whois_queue(buffer, USERHOST_USERHOST,
-					null(char *));
+					NULL);
 				n = 0;
 			}
 		}
 	}
 	if (n)
-		add_to_whois_queue(buffer, USERHOST_USERHOST, null(char *));
+		add_to_whois_queue(buffer, USERHOST_USERHOST, NULL);
 	else if (!total)
 		/* Default to yourself.  */
 		add_to_whois_queue(get_server_nickname(from_server),
-				USERHOST_USERHOST, null(char *));
+				USERHOST_USERHOST, NULL);
 }
 
 /*
@@ -1092,7 +1088,7 @@ char	*command,
 	*args;
 {
 	char	*arg,
-		*channel = null(char *);
+		*channel = NULL;
 	int	no_args = 1,
 		len;
 
@@ -1251,12 +1247,12 @@ char	*command,
 	char	*nick,
 		*rest;
 
-	message_from(null(char *), LOG_CURRENT);
+	message_from(NULL, LOG_CURRENT);
 	if (nick = next_arg(args, &rest))
 	{
 		if (strcmp(nick, ".") == 0)
 		{
-			if ((nick = sent_nick) == null(char *))
+			if (!(nick = sent_nick))
 			{
 				say("You have not messaged anyone yet");
 				return;
@@ -1264,7 +1260,7 @@ char	*command,
 		}
 		else if (strcmp(nick, ",") == 0)
 		{
-			if ((nick = recv_nick) == null(char *))
+			if (!(nick = recv_nick))
 			{
 				say("You have not recieved a message from \
 						anyone yet");
@@ -1272,7 +1268,7 @@ char	*command,
 			}
 		}
 		else if (strcmp(nick, "*") == 0)
-			if ((nick=get_channel_by_refnum(0)) == null(char *))
+			if (!(nick = get_channel_by_refnum(0)))
 			{
 				say("You are not on a channel");
 				return;
@@ -1283,7 +1279,7 @@ char	*command,
 			if (is_process(nick) == 0)
 			{
 				say("Invalid processes specification");
-				message_from(null(char *), LOG_CRAP);
+				message_from(NULL, LOG_CRAP);
 				return;
 			}
 		}
@@ -1295,13 +1291,13 @@ char	*command,
 		if (query_nick())
 		{
 			say("Ending conversation with %s", query_nick());
-			set_query_nick(null(char *));
+			set_query_nick(NULL);
 		}
 		else
 			say("You aren't querying anyone!");
 	}
 	update_input(UPDATE_ALL);
-	message_from(null(char *), LOG_CRAP);
+	message_from(NULL, LOG_CRAP);
 }
 
 /*
@@ -1313,7 +1309,7 @@ char	*command,
 	*args;
 {
 	int	len;
-	char	*arg = null(char *);
+	char	*arg = NULL;
 	int	flag = AWAY_ONE;
 	int	i;
 
@@ -1380,9 +1376,9 @@ char	*command,
 	update_all_status();
 }
 
-/* quit: The /QUIT, /EXIT, etc command */
+/* e_quit: The /QUIT, /EXIT, etc command */
 /*ARGSUSED*/
-static	void	quit(command, args)
+static	void	e_quit(command, args)
 char	*command,
 	*args;
 {
@@ -1418,33 +1414,33 @@ char	*command,
 	say("Done");
 }
 
-/* wall: used for WALL and WALLOPS */
-static	void	wall(command, args)
+/* e_wall: used for WALL and WALLOPS */
+static	void	e_wall(command, args)
 char	*command,
 	*args;
 {
 	if (strcmp(command, "WALL") == 0)
 	{	/* I hate this */
-		message_from(null(char *), LOG_WALL);
+		message_from(NULL, LOG_WALL);
 		if (!get_server_operator(from_server))
 			put_it("## %s", args);
 	}
 	else
 	{
-		message_from(null(char *), LOG_WALLOP);
+		message_from(NULL, LOG_WALLOP);
 		if (!get_server_flag(from_server, USER_MODE_W))
 			put_it("!! %s", args);
 	}
 	if (!in_on_who)
 		send_to_server("%s :%s", command, args);
-	message_from(null(char *), LOG_CRAP);
+	message_from(NULL, LOG_CRAP);
 }
 
 /*
- * privmsg: The MSG command, displaying a message on the screen indicating
+ * e_privmsg: The MSG command, displaying a message on the screen indicating
  * the message was sent.  Also, this works for the NOTICE command. 
  */
-static	void	privmsg(command, args)
+static	void	e_privmsg(command, args)
 char	*command,
 	*args;
 {
@@ -1477,26 +1473,23 @@ char	*command,
 #endif
 		if (strcmp(nick, ".") == 0)
 		{
-			if ((nick = sent_nick) == null(char *))
+			if (!(nick = sent_nick))
 			{
-				say("You have not sent a \
-message to anyone yet");
+				say("You have not sent a message to anyone yet");
 				return;
 			}
 		}
 
 		else if (strcmp(nick, ",") == 0)
 		{
-			if ((nick = recv_nick) == null(char *))
+			if (!(nick = recv_nick))
 			{
-				say("You have not received a message \
-from anyone yet");
+				say("You have not received a message from anyone yet");
 				return;
 			}
 		}
 		else if (!strcmp(nick, "*"))
-			if ((nick = get_channel_by_refnum(0)) ==
-					null(char *))
+			if (!(nick = get_channel_by_refnum(0)))
 				nick = "0";
 		send_text(nick, args, command);
 	}
@@ -1634,16 +1627,21 @@ static	void	send_channel_com(command, args)
 char	*command,
 	*args;
 {
-	char	*ptr;
+	char	*ptr,
+		*s;
 
 	if (ptr = index(args, ' '))
 		*(ptr++) = null(char);
 	else
 		ptr = index(args, null(char));
 
-	if (strcmp(args, "*") == 0)
-		send_to_server("%s %s %s", command, get_channel_by_refnum(0),
-			ptr);
+	if (!strcmp(args, "*"))
+	{
+		if (s = get_channel_by_refnum(0))
+			send_to_server("%s %s %s", command, s, ptr);
+		else
+			say("You aren't on a channel in this window");
+	}
 	else
 		send_to_server("%s %s %s", command, args, ptr);
 }
@@ -1666,12 +1664,12 @@ char	*command;
 	char	*key,
 		*ptr,
 		*free_nick,
-		*nick = null(char *);
+		*nick = NULL;
 	int	lastlog_level,
 		list_type,
 		old_server;
 	char	the_thing;
-	char	*query_command = null(char *);
+	char	*query_command = NULL;
 
 	malloc_strcpy(&nick, org_nick);
 	free_nick = ptr = nick;
@@ -1739,7 +1737,7 @@ ON WHOIS");
 			command = "NOTICE";
 			break;
 		case NOTICE_LIST:
-			echo(null(char *), "*** You cannot send a message  \
+			echo(NULL, "*** You cannot send a message  \
 from a NOTICE");
 			new_free(&free_nick);
 			return;
@@ -1749,7 +1747,7 @@ from a NOTICE");
 			int	current;
 
 			current = is_current_channel(nick, 0);
-			if ((command == null(char *)) || strcmp(command,
+			if (!command || strcmp(command,
 					"NOTICE"))
 			{
 				command = "PRIVMSG";
@@ -1777,8 +1775,7 @@ from a NOTICE");
 			}
 			if (key = is_crypted(nick))
 			{
-				if ((line = crypt_msg(line, key, 1)) ==
-						null(char *))
+				if (!(line = crypt_msg(line, key, 1)))
 					continue;
 			}
 			set_lastlog_msg_level(lastlog_level);
@@ -1795,7 +1792,7 @@ from a NOTICE");
 		}
 		else
 		{
-			if ((command == null(char *)) || strcmp(command,
+			if (!command || strcmp(command,
 					"NOTICE"))
 			{
 				lastlog_level = set_lastlog_msg_level(LOG_MSG);
@@ -1818,8 +1815,7 @@ from a NOTICE");
 					the_thing, line);
 			if (key = is_crypted(nick))
 			{
-				if ((line = crypt_msg(line, key, 1)) ==
-						null(char *))
+				if (!(line = crypt_msg(line, key, 1)))
 					continue;
 			}
 			set_lastlog_msg_level(lastlog_level);
@@ -1844,7 +1840,7 @@ messages from %s", nick);
 				away("AWAY", empty_string);
 		}
 	}
-	message_from(null(char *), LOG_CRAP);
+	message_from(NULL, LOG_CRAP);
 	new_free(&free_nick);
 }
 
@@ -1858,7 +1854,7 @@ char	*command,
 		tmp = get_channel_by_refnum(0);
 	else
 		tmp = get_target_by_refnum(0);
-	send_text(tmp, args, null(char *));
+	send_text(tmp, args, NULL);
 }
 
 /*
@@ -1873,8 +1869,8 @@ void	command_completion()
 		i,
 		c,
 		len;
-	char	**aliases = null(char **);
-	char	*line = null(char *),
+	char	**aliases = NULL;
+	char	*line = NULL,
 		*com,
 		*cmdchars,
 		*rest;
@@ -1883,7 +1879,7 @@ void	command_completion()
 	malloc_strcpy(&line, get_input());
 	if (com = next_arg(line, &rest))
 	{
-		if ((cmdchars = get_string_var(CMDCHARS_VAR)) == null(char *))
+		if (!(cmdchars = get_string_var(CMDCHARS_VAR)))
 			cmdchars = DEFAULT_CMDCHARS;
 		if (index(cmdchars, *com))
 		{
@@ -2018,7 +2014,7 @@ char	*name,
 int	hist_flag,
 	append_flag;
 {
-	char	*line = null(char *),
+	char	*line = NULL,
 		*ptr,
 		*start,
 		*free_line,
@@ -2096,7 +2092,7 @@ char	*sub_args;
 			old_display_var;
 	char	*cmdchars,
 		*com,
-		*this_cmd = null(char *);
+		*this_cmd = NULL;
 	int	args_flag,
 		add_to_hist,
 		cmdchar_used;
@@ -2105,7 +2101,7 @@ char	*sub_args;
 	if (get_int_var(DEBUG_VAR) & DEBUG_COMMANDS)
 		yell("Executing [%d] %s", level, line);
 	level++;
-	if ((cmdchars = get_string_var(CMDCHARS_VAR)) == null(char *))
+	if (!(cmdchars = get_string_var(CMDCHARS_VAR)))
 		cmdchars = DEFAULT_CMDCHARS;
 	malloc_strcpy(&this_cmd, line);
 	add_to_hist = 1;
@@ -2125,7 +2121,7 @@ char	*sub_args;
 	 */
 	if (hist_flag && !cmdchar_used && !get_int_var(COMMAND_MODE_VAR))
 	{
-		do_send_text(null(char *), line);
+		do_send_text(NULL, line);
 		if (hist_flag && add_to_hist)
 		{
 			add_to_history(this_cmd);
@@ -2135,7 +2131,7 @@ char	*sub_args;
 	}
 	else if (*com == '\'' && get_int_var(COMMAND_MODE_VAR))
 	{
-		do_send_text(null(char *), line+1);
+		do_send_text(NULL, line+1);
 		if (hist_flag && add_to_hist)
 		{
 			add_to_history(this_cmd);
@@ -2145,7 +2141,7 @@ char	*sub_args;
 #if 0 /* ':' is the no-op command. */
 	else if (*com == ':' && get_int_var(COMMAND_MODE_VAR))
 	{
-		me(null(char *), line+1);
+		me(NULL, line+1);
 		if (hist_flag && add_to_hist)
 		{
 			add_to_history(this_cmd);
@@ -2170,7 +2166,7 @@ char	*sub_args;
 	else
 	{
 		char	*rest,
-			*alias = null(char *),
+			*alias = NULL,
 			*alias_name;
 		int	cmd_cnt,
 			alias_cnt;
@@ -2264,7 +2260,7 @@ char	*sub_args;
 					execute_alias(alias_name, alias, rest);
 				else if (!stricmp(com, nickname))
 						/* nick = /me  -lynx */
-					me(null(char *), rest);
+					me(NULL, rest);
 				else
 					say("Unknown command: %s", com);
 			}
@@ -2291,19 +2287,19 @@ char	*command,
 {
 	FILE	*fp;
 	char	*filename,
-		*expanded = null(char *);
+		*expanded = NULL;
 	int	flag = 0;
 	struct	stat	stat_buf;
 	int	paste_level = 0;
 	char	*start,
-		*current_row = null(char *),
+		*current_row = NULL,
 		buffer[BIG_BUFFER_SIZE + 1];
 	int	no_semicolon = 1;
 	char	*irc_path;
 	int	display;
 #ifdef ZCAT
 	char	*temp;
-	char	*expand_z = null(char *);
+	char	*expand_z = NULL;
 	int	exists;
 #endif
 
@@ -2352,14 +2348,14 @@ char	*command,
 			if (*expanded != '/')
 			{
 #ifdef ZCAT
-				if ((filename = path_search(expanded, irc_path))
-						== null(char *))
+				if (!(filename = path_search(expanded,
+				    irc_path)))
 					filename = path_search(expand_z,
 						irc_path);
-				if (filename == null(char *))
+				if (!filename)
 #else
-					if ((filename = path_search(expanded,
-						irc_path)) == null(char *))
+					if (!(filename = path_search(expanded,
+						irc_path)))
 #endif /*ZCAT*/
 					{
 						say("%s: File not found",
@@ -2435,7 +2431,7 @@ not be loaded", expanded);
 					window_display = 0;
 					current_row = NULL;
 					if (!flag)
-						args = null(char *);
+						args = NULL;
 					for (;;)
 					{
 						if (fgets(buffer,
@@ -2479,7 +2475,7 @@ not be loaded", expanded);
 			{
 				if (!paste_level)
 				{
-					parse_line(null(char *), current_row,
+					parse_line(NULL, current_row,
 						args, 0, 0);
 					new_free(&current_row);
 				}
@@ -2528,7 +2524,7 @@ not be loaded", expanded);
 			else
 			{
 				malloc_strcat(&current_row, start);
-				start = null(char *);
+				start = NULL;
 			}
 		}
 	}
@@ -2543,7 +2539,7 @@ not be loaded", expanded);
 						if (paste_level)
 							yell("Unexpected EOF");
 						else
-							parse_line(null(char *),
+							parse_line(NULL,
 								current_row, 
 								args, 0, 0);
 						new_free(&current_row);
@@ -2615,7 +2611,7 @@ void	(*ptr)();
 	else
 	{
 		char	*line,
-			*tmp = null(char *);
+			*tmp = NULL;
 
 		line = get_input();
 		malloc_strcpy(&tmp, line);
@@ -2623,10 +2619,10 @@ void	(*ptr)();
 		if (do_hook(INPUT_LIST, "%s", tmp))
 		{
 			if (get_int_var(INPUT_ALIASES_VAR))
-				parse_line(null(char *), tmp, empty_string,
+				parse_line(NULL, tmp, empty_string,
 					1, 0);
 			else
-				parse_line(null(char *), tmp, null(char *),
+				parse_line(NULL, tmp, NULL,
 					1, 0);
 		}
 		update_input(UPDATE_ALL);
@@ -2647,9 +2643,9 @@ char	*command,
 	display = window_display;
 	window_display = 1;
 	if (get_int_var(INPUT_ALIASES_VAR))
-		parse_line(null(char *), args, empty_string, 1, 0);
+		parse_line(NULL, args, empty_string, 1, 0);
 	else
-		parse_line(null(char *), args, null(char *), 1, 0);
+		parse_line(NULL, args, NULL, 1, 0);
 	update_input(UPDATE_ALL);
 	window_display = display;
 	from_server = server;
@@ -2713,7 +2709,7 @@ char	c,
 	*str;
 {
 	hold_mode(null(Window *), OFF, 1);
-	clear(null(char *), empty_string);
+	clear(NULL, empty_string);
 }
 
 /* parse_text: the bindable function that executes its string */
@@ -2721,7 +2717,7 @@ void	parse_text(c, str)
 char	c,
 	*str;
 {
-	parse_line(null(char *), str, empty_string, 0, 0);
+	parse_line(NULL, str, empty_string, 0, 0);
 }
 
 /*
@@ -2860,7 +2856,7 @@ char	*target, *text;
 	send_ctcp(ctcp_type[CTCP_PRIVMSG], target, "ACTION", text);
 }
 
-#if 0
+#if LYNX_STUFF
 static	char*	prepare_action(string)
 char*	string;
 {
@@ -2896,12 +2892,12 @@ char	*command,
 	{
 		int	old;
 		int	from_level;
-#if 0
+#if LYNX_STUFF
 		char	*result;
 #endif
 		char	*message;
 
-#if 0
+#if LYNX_STUFF
 		if (result = prepare_action(args))
 			message = result;
 		else
@@ -2917,7 +2913,7 @@ char	*command,
 		set_lastlog_msg_level(old);
 		message_from_level(from_level);
 
-#if 0
+#if LYNX_STUFF
 		if (result)
 			new_free(&result);
 #endif
@@ -2943,7 +2939,7 @@ char	*command,
 		{
 			int	old;
 			int	from_level;
-#if 0
+#if LYNX_STUFF
 			char	*result;
 #endif
 			char	*message;
@@ -2956,7 +2952,7 @@ char	*command,
 query");
 					return;
 				}
-#if 0
+#if LYNX_STUFF
 			if (result = prepare_action(args))
 				message = result;
 			else
@@ -2972,7 +2968,7 @@ query");
 			set_lastlog_msg_level(old);
 			message_from_level(from_level);
 
-#if 0
+#if LYNX_STUFF
 			if (result)
 				new_free(&result);
 #endif
@@ -3009,7 +3005,7 @@ char	*command,
 	*args,
 	*subargs;
 {
-	parse_line(null(char *), args, subargs ? subargs : empty_string, 0, 0);
+	parse_line(NULL, args, subargs ? subargs : empty_string, 0, 0);
 }
 
 /*
@@ -3139,7 +3135,7 @@ char	*args;
 	ntimer = (TimerList *) new_malloc(sizeof(TimerList));
 	ntimer->time = current + atol(waittime);
 	ntimer->ref = refnum;
-	ntimer->command = null(char *);
+	ntimer->command = NULL;
 	malloc_strcpy(&ntimer->command, args);
 
 	/* we've created it, now put it in order */
@@ -3264,7 +3260,7 @@ void	eval_inputlist(args, line)
 char	*args,
 	*line;
 {
-	parse_line(null(char *), args, line ? line : empty_string, 0, 0);
+	parse_line(NULL, args, line ? line : empty_string, 0, 0);
 }
 
 /* pingcmd: ctcp ping, duh - phone, jan 1993. */
