@@ -18,12 +18,7 @@
 #endif /* ISC22 */
 #ifdef XD88
 #define ISC22
-#endif
-/* #if defined(ESIX) || defined(XD88) /* */
-#if defined(ESIX)
-#include <lan/net_types.h>
-#endif /* ESIX */
-/* #endif /* ESIX || XD88 */
+#endif /* XD88 */
 #ifdef POSIX
 # include <sys/select.h>
 #endif /* POSIX */
@@ -68,7 +63,7 @@ typedef struct
 	List	*waitcmds;		/* commands queued by WAIT -CMD */
 }	Process;
 
-static	Process **process_list = null(Process **);
+static	Process **process_list = NULL;
 static	int	process_list_size = 0;
 
 /*
@@ -130,49 +125,44 @@ int	index;
  */
 void	check_wait_status()
 {
-#if !defined(ISC22) && !defined(SVR4) && !defined(POSIX) && !defined(__386BSD__)
-	union wait status;
-#else
+	Process	*proc;
+#if defined(ISC22) || defined(SVR4) || defined(POSIX) || defined(__386BSD__) || defined(UNICOS)
 	int	status;
+#else
+	union wait status;
 #endif /* !defined(ISC22) && !defined(SVR4) */
 	int	pid,
 		i;
 
 #if defined(use_wait2) || defined(MUNIX)
 	if ((pid = wait2(&status, WNOHANG, 0)) > 0)
-	{
 #else
-# if defined(ISC22) || defined(SVR4) || defined(POSIX) || defined(__386BSD__)
+# if defined(ISC22) || defined(SVR4) || defined(POSIX) || defined(__386BSD__) || defined(UNICOS)
 	if ((pid = waitpid(-1, &status, WNOHANG)) > 0)
-	{
 # else
 	if ((pid = wait3(&status, WNOHANG, NULL)) > 0)
-	{
 # endif /* defined(ISC22) || defined (SVR4) */
 #endif /* defined(use_wait2) || defined(MUNIX) */
+	{
 		errno = 0;	/* reset errno, cause wait3 changes it */
 		for (i = 0; i < process_list_size; i++)
 		{
-			if (process_list[i] && (process_list[i]->pid == pid))
+			if ((proc = process_list[i]) && proc->pid == pid)
 			{
-				process_list[i]->exited = 1;
-#if !defined(ISC22) && !defined(SVR4) && !defined(POSIX) && !defined(linux) && !defined(__386BSD__)
-				process_list[i]->termsig = status.w_T.w_Termsig;
-				process_list[i]->retcode = status.w_T.w_Retcode;
+				proc->exited = 1;
+#if defined(ISC22) || defined(SVR4) || defined(POSIX) || defined(linux) || defined(__386BSD__) || defined(UNICOS)
+				proc->termsig = WTERMSIG(status);
+				proc->retcode = WEXITSTATUS(status);
 #else
-				process_list[i]->termsig = WTERMSIG(status);
-				process_list[i]->retcode = WEXITSTATUS(status);
+				proc->termsig = status.w_T.w_Termsig;
+				proc->retcode = status.w_T.w_Retcode;
 #endif /* !defined(ISC22) && !defined(SVR4) */
-				if ((process_list[i]->p_stderr == -1) &&
-				    (process_list[i]->p_stdout == -1))
+				if ((proc->p_stderr == -1) &&
+				    (proc->p_stdout == -1))
 					delete_process(i);
 				return;
 			}
 		}
-#if 0	/* to match the braces above */
-	}
-	}
-#endif
 	}
 }
 
@@ -185,19 +175,20 @@ void	check_process_limits()
 {
 	int	limit;
 	int	i;
+	Process	*proc;
 
 	if ((limit = get_int_var(SHELL_LIMIT_VAR)) && process_list)
 	{
 		for (i = 0; i < process_list_size; i++)
 		{
-			if (process_list[i])
+			if (proc = process_list[i])
 			{
-				if (process_list[i]->counter >= limit)
+				if (proc->counter >= limit)
 				{
-					process_list[i]->p_stdin = exec_close(process_list[i]->p_stdin);
-					process_list[i]->p_stdout = exec_close(process_list[i]->p_stdout);
-					process_list[i]->p_stderr = exec_close(process_list[i]->p_stderr);
-					if (process_list[i]->exited)
+					proc->p_stdin = exec_close(proc->p_stdin);
+					proc->p_stdout = exec_close(proc->p_stdout);
+					proc->p_stderr = exec_close(proc->p_stderr);
+					if (proc->exited)
 						delete_process(i);
 				}
 			}
@@ -217,15 +208,16 @@ fd_set	*rd;
 		flag;
 	char	exec_buffer[INPUT_BUFFER_SIZE + 1];
 	char	*ptr;
+	Process	*proc;
 
 	if (process_list == null(Process **))
 		return;
 	dgets_timeout(1L);
 	for (i = 0; i < process_list_size && !break_io_processing; i++)
 	{
-		if (process_list[i] && (process_list[i]->p_stdout != -1))
+		if ((proc = process_list[i]) && proc->p_stdout != -1)
 		{
-			if (FD_ISSET(process_list[i]->p_stdout, rd))
+			if (FD_ISSET(proc->p_stdout, rd))
 			{
 
 	/*
@@ -233,37 +225,37 @@ fd_set	*rd;
 	 * phone, jan 1993.
 	 */
 		switch (dgets(exec_buffer, INPUT_BUFFER_SIZE,
-				process_list[i]->p_stdout))
+				proc->p_stdout))
 		{
 		case 0:
-			if (process_list[i]->p_stderr == -1)
+			if (proc->p_stderr == -1)
 			{
-				process_list[i]->p_stdin =
-					exec_close(process_list[i]->p_stdin);
-				process_list[i]->p_stdout =
-					exec_close(process_list[i]->p_stdout);
-				if (process_list[i]->exited)
+				proc->p_stdin =
+					exec_close(proc->p_stdin);
+				proc->p_stdout =
+					exec_close(proc->p_stdout);
+				if (proc->exited)
 					delete_process(i);
 			}
 			else
-				process_list[i]->p_stdout =
-					exec_close(process_list[i]->p_stdout);
+				proc->p_stdout =
+					exec_close(proc->p_stdout);
 			break;
 		case -1:
-			if (process_list[i]->logical)
+			if (proc->logical)
 				flag = do_hook(EXEC_PROMPT_LIST, "%s %s",
-					process_list[i]->logical, exec_buffer);
+					proc->logical, exec_buffer);
 			else
 				flag = do_hook(EXEC_PROMPT_LIST, "%d %s", i,
 					exec_buffer);
-			set_prompt_by_refnum(process_list[i]->refnum,
+			set_prompt_by_refnum(proc->refnum,
 				exec_buffer);
 			update_input(UPDATE_ALL);
 			/* if (flag == 0) */
 			break;
 		default:
-			message_to(process_list[i]->refnum);
-			process_list[i]->counter++;
+			message_to(proc->refnum);
+			proc->counter++;
 			ptr = exec_buffer + strlen(exec_buffer) - 1;
 			if ((*ptr == '\n') || (*ptr == '\r'))
 			{
@@ -272,23 +264,23 @@ fd_set	*rd;
 				if ((*ptr == '\n') || (*ptr == '\r'))
 					*ptr = null(char);
 			}
-			if (process_list[i]->logical)
+			if (proc->logical)
 				flag = do_hook(EXEC_LIST, "%s %s",
-					process_list[i]->logical, exec_buffer);
+					proc->logical, exec_buffer);
 			else
 				flag = do_hook(EXEC_LIST, "%d %s", i,
 					exec_buffer);
 			if (flag)
 			{
-				if (process_list[i]->redirect)
+				if (proc->redirect)
 				{
 					int	server;
 
 					server = from_server;
-					from_server = process_list[i]->server;
-					send_text(process_list[i]->who,
+					from_server = proc->server;
+					send_text(proc->who,
 						exec_buffer,
-						process_list[i]->redirect);
+						proc->redirect);
 					from_server = server;
 				}
 				else
@@ -302,46 +294,46 @@ fd_set	*rd;
 
 			}
 		}
-		if (process_list && (i < process_list_size) &&
-		    process_list[i] && (process_list[i]->p_stderr != -1))
+		if (process_list && i < process_list_size &&
+		    (proc = process_list[i]) && proc->p_stderr != -1)
 		{
-			if (FD_ISSET(process_list[i]->p_stderr, rd))
+			if (FD_ISSET(proc->p_stderr, rd))
 			{
 
 	/* Do the intendation on this switch as well */
 
 		switch (dgets(exec_buffer, INPUT_BUFFER_SIZE,
-				process_list[i]->p_stderr))
+				proc->p_stderr))
 		{
 		case 0:
-			if (process_list[i]->p_stdout == -1)
+			if (proc->p_stdout == -1)
 			{
-				process_list[i]->p_stderr =
-					exec_close(process_list[i]->p_stderr);
-				process_list[i]->p_stdin =
-					exec_close(process_list[i]->p_stdin);
-				if (process_list[i]->exited)
+				proc->p_stderr =
+					exec_close(proc->p_stderr);
+				proc->p_stdin =
+					exec_close(proc->p_stdin);
+				if (proc->exited)
 					delete_process(i);
 			}
 			else
-				process_list[i]->p_stderr =
-					exec_close(process_list[i]->p_stderr);
+				proc->p_stderr =
+					exec_close(proc->p_stderr);
 			break;
 		case -1:
-			if (process_list[i]->logical)
+			if (proc->logical)
 				flag = do_hook(EXEC_PROMPT_LIST, "%s %s",
-					process_list[i]->logical, exec_buffer);
+					proc->logical, exec_buffer);
 			else
 				flag = do_hook(EXEC_PROMPT_LIST, "%d %s", i,
 					exec_buffer);
-			set_prompt_by_refnum(process_list[i]->refnum,
+			set_prompt_by_refnum(proc->refnum,
 				exec_buffer);
 			update_input(UPDATE_ALL);
 			if (flag == 0)
 				break;
 		default:
-			message_to(process_list[i]->refnum);
-			(process_list[i]->counter)++;
+			message_to(proc->refnum);
+			(proc->counter)++;
 			ptr = exec_buffer + strlen(exec_buffer) - 1;
 			if ((*ptr == '\n') || (*ptr == '\r'))
 			{
@@ -350,21 +342,21 @@ fd_set	*rd;
 				if ((*ptr == '\n') || (*ptr == '\r'))
 					*ptr = null(char);
 			}
-			if (process_list[i]->logical)
+			if (proc->logical)
 				flag = do_hook(EXEC_ERRORS_LIST, "%s %s",
-					process_list[i]->logical, exec_buffer);
+					proc->logical, exec_buffer);
 			else
 				flag = do_hook(EXEC_ERRORS_LIST, "%d %s", i,
 					exec_buffer);
 			if (flag)
 			{
-				if (process_list[i]->redirect)
+				if (proc->redirect)
 				{
 					int	server;
 
 					server = from_server;
-					from_server = process_list[i]->server;
-					send_text(process_list[i]->who,
+					from_server = proc->server;
+					send_text(proc->who,
 						exec_buffer,
 						process_list[i]->redirect);
 					from_server = server;
@@ -392,17 +384,18 @@ void	set_process_bits(rd)
 fd_set	*rd;
 {
 	int	i;
+	Process	*proc;
 
 	if (process_list)
 	{
 		for (i = 0; i < process_list_size; i++)
 		{
-			if (process_list[i])
+			if (proc = process_list[i])
 			{
-				if (process_list[i]->p_stdout != -1)
-					FD_SET(process_list[i]->p_stdout, rd);
-				if (process_list[i]->p_stderr != -1)
-					FD_SET(process_list[i]->p_stderr, rd);
+				if (proc->p_stdout != -1)
+					FD_SET(proc->p_stdout, rd);
+				if (proc->p_stderr != -1)
+					FD_SET(proc->p_stderr, rd);
 			}
 		}
 	}
@@ -414,6 +407,7 @@ fd_set	*rd;
  */
 static	void	list_processes()
 {
+	Process	*proc;
 	int	i;
 
 	if (process_list)
@@ -421,15 +415,15 @@ static	void	list_processes()
 		say("Process List:");
 		for (i = 0; i < process_list_size; i++)
 		{
-			if (process_list[i])
+			if (proc = process_list[i])
 			{
-				if (process_list[i]->logical)
+				if (proc->logical)
 					say("\t%d (%s): %s", i,
-						process_list[i]->logical,
-						process_list[i]->name);
+						proc->logical,
+						proc->name);
 				else
 					say("\t%d: %s", i,
-						process_list[i]->name);
+						proc->name);
 			}
 		}
 	}
@@ -524,12 +518,10 @@ int	index;
 				if (get_int_var(NOTIFY_ON_TERMINATION_VAR))
 				{
 					if (dead->termsig)
-						say("Process %d (%s) \
-terminated with signal %s (%d)", index, dead->name, signals[dead->termsig],
+						say("Process %d (%s) terminated with signal %s (%d)", index, dead->name, signals[dead->termsig],
 							dead->termsig);
 					else
-						say("Process %d (%s) \
-terminated with return code %d", index, dead->name, dead->retcode);
+						say("Process %d (%s) terminated with return code %d", index, dead->name, dead->retcode);
 				}
 			}
 			new_free(&dead->name);
@@ -561,6 +553,7 @@ char	*who;
 unsigned int	refnum;
 {
 	int	i;
+	Process	*proc;
 
 	if (process_list == null(Process **))
 	{
@@ -570,30 +563,30 @@ unsigned int	refnum;
 	}
 	for (i = 0; i < process_list_size; i++)
 	{
-		if (process_list[i] == null(Process *))
+		if (!process_list[i])
 		{
-			process_list[i] = (Process *)
+			proc = process_list[i] = (Process *)
 				new_malloc(sizeof(Process));
-			process_list[i]->name = null(char *);
-			malloc_strcpy(&(process_list[i]->name), name);
-			process_list[i]->logical = null(char *);
-			malloc_strcpy(&(process_list[i]->logical), logical);
-			process_list[i]->pid = pid;
-			process_list[i]->p_stdin = p_stdin;
-			process_list[i]->p_stdout = p_stdout;
-			process_list[i]->p_stderr = p_stderr;
-			process_list[i]->refnum = refnum;
-			process_list[i]->redirect = null(char *);
+			proc->name = null(char *);
+			malloc_strcpy(&(proc->name), name);
+			proc->logical = null(char *);
+			malloc_strcpy(&(proc->logical), logical);
+			proc->pid = pid;
+			proc->p_stdin = p_stdin;
+			proc->p_stdout = p_stdout;
+			proc->p_stderr = p_stderr;
+			proc->refnum = refnum;
+			proc->redirect = null(char *);
 			if (redirect)
-				malloc_strcpy(&(process_list[i]->redirect),
+				malloc_strcpy(&(proc->redirect),
 					redirect);
-			process_list[i]->server = curr_scr_win->server;
-			process_list[i]->counter = 0;
-			process_list[i]->exited = 0;
-			process_list[i]->termsig = 0;
-			process_list[i]->retcode = 0;
-			process_list[i]->who = null(char *);
-			process_list[i]->waitcmds = null(List *);
+			proc->server = curr_scr_win->server;
+			proc->counter = 0;
+			proc->exited = 0;
+			proc->termsig = 0;
+			proc->retcode = 0;
+			proc->who = null(char *);
+			proc->waitcmds = null(List *);
 			if (who)
 				malloc_strcpy(&(process_list[i]->who), who);
 			return;
@@ -603,28 +596,28 @@ unsigned int	refnum;
 	process_list = (Process **) new_realloc(process_list, sizeof(Process *)
 		* process_list_size);
 	process_list[process_list_size - 1] = null(Process *);
-	process_list[i] = (Process *) new_malloc(sizeof(Process));
-	process_list[i]->name = null(char *);
-	malloc_strcpy(&(process_list[i]->name), name);
-	process_list[i]->logical = null(char *);
-	malloc_strcpy(&(process_list[i]->logical), logical);
-	process_list[i]->pid = pid;
-	process_list[i]->p_stdin = p_stdin;
-	process_list[i]->p_stdout = p_stdout;
-	process_list[i]->p_stderr = p_stderr;
-	process_list[i]->refnum = refnum;
-	process_list[i]->redirect = null(char *);
+	proc = process_list[i] = (Process *) new_malloc(sizeof(Process));
+	proc->name = null(char *);
+	malloc_strcpy(&(proc->name), name);
+	proc->logical = null(char *);
+	malloc_strcpy(&(proc->logical), logical);
+	proc->pid = pid;
+	proc->p_stdin = p_stdin;
+	proc->p_stdout = p_stdout;
+	proc->p_stderr = p_stderr;
+	proc->refnum = refnum;
+	proc->redirect = null(char *);
 	if (redirect)
-		malloc_strcpy(&(process_list[i]->redirect), redirect);
-	process_list[i]->server = curr_scr_win->server;
-	process_list[i]->counter = 0;
-	process_list[i]->exited = 0;
-	process_list[i]->termsig = 0;
-	process_list[i]->retcode = 0;
-	process_list[i]->who = null(char *);
-	process_list[i]->waitcmds = null(List *);
+		malloc_strcpy(&(proc->redirect), redirect);
+	proc->server = curr_scr_win->server;
+	proc->counter = 0;
+	proc->exited = 0;
+	proc->termsig = 0;
+	proc->retcode = 0;
+	proc->who = null(char *);
+	proc->waitcmds = null(List *);
 	if (who)
-		malloc_strcpy(&(process_list[i]->who), who);
+		malloc_strcpy(&(proc->who), who);
 }
 
 /*
@@ -658,18 +651,15 @@ static	void	kill_process(index, signal)
 static	int	is_logical_unique(logical)
 	char	*logical;
 {
+	Process	*proc;
 	int	i;
 
 	if (logical)
-	{
 		for (i = 0; i < process_list_size; i++)
-		{
-			if (process_list[i] && process_list[i]->logical &&
-			    (stricmp(process_list[i]->logical, logical) == 0))
-				return (0);
-		}
-	}
-	return (1);
+			if ((proc = process_list[i]) && proc->logical &&
+			    (stricmp(proc->logical, logical) == 0))
+				return 0;
+	return 1;
 }
 
 /*
@@ -692,6 +682,13 @@ unsigned int	refnum;
 		*flag,
 		*arg;
 
+#ifdef DAEMON_UID
+	if (getuid() == DAEMON_UID)
+	{
+		say("Sorry, you are not allowed to use EXEC");
+		return;
+	}
+#endif /* DAEMON_UID */
 	p0[0] = p0[1] = -1;
 	p1[0] = p1[1] = -1;
 	p2[0] = p2[1] = -1;
@@ -798,6 +795,7 @@ char	*text;
 int	show;
 {
 	int	ref;
+	Process	*proc;
 
 	if (valid_process_index(index) == 0)
 	{
@@ -805,11 +803,12 @@ int	show;
 		return (1);
 	}
 	ref = process_list[index]->refnum;
+	proc = process_list[index];
 	message_to(ref);
 	if (show)
 		put_it("%s%s", get_prompt_by_refnum(ref), text); /* lynx */
-	write(process_list[index]->p_stdin, text, strlen(text));
-	write(process_list[index]->p_stdin, "\n", 1);
+	write(proc->p_stdin, text, strlen(text));
+	write(proc->p_stdin, "\n", 1);
 	set_prompt_by_refnum(ref, empty_string);
 	/*  update_input(UPDATE_ALL); */
 	message_to(0);
@@ -835,15 +834,16 @@ int	is_process_running(index)
 int	logical_to_index(logical)
 	char	*logical;
 {
+	Process	*proc;
 	int	i;
 
 	for (i = 0; i < process_list_size; i++)
 	{
-		if (process_list[i] && process_list[i]->logical &&
-		    (stricmp(process_list[i]->logical, logical) == 0))
-			return (i);
+		if ((proc = process_list[i]) && proc->logical &&
+		    (stricmp(proc->logical, logical) == 0))
+			return i;
 	}
-	return (-1);
+	return -1;
 }
 
 /*
@@ -901,16 +901,15 @@ char	*command,
 		i,
 		refnum_flag = 0,
 		logical_flag = 0;
+	Process	*proc;
 
 	if (get_int_var(EXEC_PROTECTION_VAR) && (send_text_flag != -1))
 	{
-		echo(null(char *),"*** WARNING:  You are attempting to use \
-EXEC from within an ON function!");
+		echo(NULL, "*** Attempt to use EXEC from within an ON function!");
 		sprintf(buffer,"*** Command \"%s\" not executed!",args);
-		echo(null(char *),buffer);
-		echo(null(char *),"*** Please read the /HELP SET \
-EXEC_PROTECTION documentation");
-		echo(null(char *),"*** for important details about this!");
+		echo(NULL, buffer);
+		echo(NULL, "*** Please read /HELP SET EXEC_PROTECTION");
+		echo(NULL, "*** for important details about this!");
 		return;
 	}
 #ifdef DAEMON_UID
@@ -920,12 +919,12 @@ EXEC_PROTECTION documentation");
 		return;
 	}
 #endif /* DAEMON_UID */
-	if (*args == null(char))
+	if (*args == '\0')
 	{
 		list_processes();
 		return;
 	}
-	redirect = null(char *);
+	redirect = NULL;
 	while ((*args == '-') && (flag = next_arg(args, &args)))
 	{
 		if (*flag == '-')
@@ -934,8 +933,7 @@ EXEC_PROTECTION documentation");
 			if (strnicmp(flag, "OUT", len) == 0)
 			{
 				redirect = "PRIVMSG";
-				if ((who = get_channel_by_refnum(0)) ==
-						null(char *))
+				if (!(who = get_channel_by_refnum(0)))
 				{
 					say("No current channel in this window for -OUT");
 					return;
@@ -978,12 +976,10 @@ EXEC_PROTECTION documentation");
 				}
 				if (is_process_running(i))
 				{
-					process_list[i]->p_stdin =
-					  exec_close(process_list[i]->p_stdin);
-					process_list[i]->p_stdout =
-					  exec_close(process_list[i]->p_stdout);
-					process_list[i]->p_stderr =
-					  exec_close(process_list[i]->p_stderr);
+				    proc = process_list[i];
+				    proc->p_stdin = exec_close(proc->p_stdin);
+				    proc->p_stdout = exec_close(proc->p_stdout);
+				    proc->p_stderr = exec_close(proc->p_stderr);
 				}
 				else
 					say("No such process running!");
@@ -1050,27 +1046,24 @@ from 1 to %d", NSIG);
 		}
 		if (valid_process_index(i))
 		{
+			proc = process_list[i];
 			message_to(refnum);
 			if (refnum_flag)
 			{
-				process_list[i]->refnum = refnum;
+				proc->refnum = refnum;
 				if (refnum)
-					say("Output from process %d (%s) \
-now going to this window", i, process_list[i]->name);
+					say("Output from process %d (%s) now going to this window", i, proc->name);
 				else
-					say("Output from process %d (%s) \
-not going to any window", i, process_list[i]->name);
+					say("Output from process %d (%s) not going to any window", i, proc->name);
 			}
-			malloc_strcpy(&(process_list[i]->redirect), redirect);
-			malloc_strcpy(&(process_list[i]->who), who);
+			malloc_strcpy(&(proc->redirect), redirect);
+			malloc_strcpy(&(proc->who), who);
 			if (redirect)
 			{
-				say("Output from process %d (%s) now going \
-to %s", i, process_list[i]->name, who);
+				say("Output from process %d (%s) now going to %s", i, proc->name, who);
 			}
 			else
-				say("Output from process %d (%s) now going \
-to you", i, process_list[i]->name);
+				say("Output from process %d (%s) now going to you", i, proc->name);
 			if (logical_flag)
 			{
 				if (logical)
@@ -1078,18 +1071,17 @@ to you", i, process_list[i]->name);
 					if (is_logical_unique(logical))
 					{
 						malloc_strcpy(&(
-						    process_list[i]->logical),
+						    proc->logical),
 						    logical);
-						say("Process %d (%s) is now c\
-alled %s", i, process_list[i]->name, process_list[i]->logical);
+						say("Process %d (%s) is now called %s",
+							i, proc->name, proc->logical);
 					}
 					else
 						say("The name %s is not unique!"
 							, logical);
 				}
 				else
-					say("The name for process %d (%s) has \
-been removed", i, process_list[i]->name);
+					say("The name for process %d (%s) has been removed", i, proc->name);
 			}
 			message_to(0);
 		}
