@@ -34,6 +34,9 @@
 #if defined(linux) || defined(SVR4) || defined (SOLARIS)
 # include <unistd.h>
 #endif /* linux || SVR4 */
+#ifdef UNICOS
+# include <sys/fcntl.h>
+#endif /* UNICOS */
 #include <sys/file.h>
 #include <sys/stat.h>
 #include <stdio.h>
@@ -47,7 +50,7 @@
 #include "screen.h"
 #include "output.h"
 
-#ifndef _IBMR2
+#if !defined(_IBMR2) && !defined(NeXT)
 # ifndef ISC22
 extern char *index();
 extern char *rindex();
@@ -57,7 +60,7 @@ extern char *strrchr();
 #  include <sys/dirent.h>
 #  define direct dirent
 # endif /* ISC22 */
-#endif
+#endif /* !defined(_IMBR2) && !defined(NeXT) */
 
 /* Forward declarations */
 
@@ -380,16 +383,16 @@ char	*name;
 static	void	help_pause_add_line(format, arg1, arg2, arg3, arg4, arg5,
 			arg6, arg7, arg8, arg9, arg10)
 char	*format;
-int	arg1,
-	arg2,
-	arg3,
-	arg4,
-	arg5,
-	arg6,
-	arg7,
-	arg8,
-	arg9,
-	arg10;
+char	*arg1,
+	*arg2,
+	*arg3,
+	*arg4,
+	*arg5,
+	*arg6,
+	*arg7,
+	*arg8,
+	*arg9,
+	*arg10;
 {
 	char	buf[BIG_BUFFER_SIZE];
 
