@@ -460,12 +460,6 @@ char	*arg1,
 	static	int hook_level = 0;
 
 	hook_level++;
-
-	/* I'm keeping this because its sooooo lame - phone, march 1993 */
-#if 0
-	for(i = 0; i < BIG_BUFFER_SIZE+1; ++i)
-		buffer[i] = '\0';
-#endif
 	bzero(buffer, sizeof(buffer));
 
 	sprintf(buffer, format, arg1, arg2, arg3, arg4, arg5, arg6);
