@@ -19,16 +19,16 @@
 #endif /* TERM */
 /* bpk <3/9/93> */
 #if defined(HPUX) || defined(ESIX) || defined(MIPS_SYSV)
-#define _TERMIOS_INCLUDED
-#define _INCLUDE_TERMIO
-#include <sys/termio.h>
+# define _TERMIOS_INCLUDED
+# define _INCLUDE_TERMIO
+# include <sys/termio.h>
 #endif
-#ifdef XD88
-#include <sys/unistd.h>
-#endif
-#if defined(SVR4) || defined(linux)
-#include <unistd.h>
+#if defined(SVR4) || defined(linux) || defined (XD88)
+# include <unistd.h>
 #endif
+#ifdef UNICOS
+# include <sys/fcntl.h>
+#endif /* UNICOS */
 #include <sys/file.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -847,41 +847,38 @@ char	*str;
 	return (str);
 }
 
+#if 0
 /* isfirst: true if c is a legal first char for a nickname */
 #define isfirst(c) (((c) >= 'A') && ((c) <= '}'))
+#endif
+
 /* islegal: true if c is a legal nickname char anywhere but first char */
-#define islegal(c) ((((c) >= '0') && ((c) <= '}')) || ((c) == '-'))
+#define islegal(c) ((((c) >= 'A') && ((c) <= '}')) || \
+		    (((c) >= '0') && ((c) <= '9')) || \
+		     ((c) == '-') || ((c) == '_'))
 
 /*
  * check_nickname: checks is a nickname is legal.  If the first character is
  * bad new, null is returned.  If the first character is bad, the string is
  * truncd down to only legal characters and returned 
+ *
+ * rewritten, with help from do_nick_name() from the server code (2.8.5),
+ * phone, april 1993.
  */
-char	*check_nickname(str)
-char	*str;
+char	*check_nickname(nick)
+char	*nick;
 {
-	char	*ptr;
+	char	*s;
 
+	if (!nick || *nick == '-' || isdigit(*nick))
+		return NULL;
 
-	if (str)
-	{
-		if (isfirst(*str))
-		{
-			for (ptr = str; *ptr; ptr++)
-			{
-				if (!(islegal(*ptr)))
-				{
-					*ptr = null(char);
-					break;
-				}
-			}
-			return (str);
-		}
-		else
-			return (null(char *));
-	}
-	else
-		return (null(char *));
+	for (s = nick; *s && (s - nick) < NICKNAME_LEN; s++)
+		if (!islegal(*s) || isspace(*s))
+			break;
+	*s = '\0';
+
+	return nick;
 }
 
 /*
