@@ -58,6 +58,7 @@ extern	void	enter_digraph();
 extern	void	scrollback_backwards();
 extern	void	scrollback_forwards();
 extern	void	scrollback_end();
+extern	void	scrollback_start();
 extern	void	enter_menu();
 
 /*
@@ -531,6 +532,7 @@ KeyMapNames key_names[] =
 	{ "SCROLL_BACKWARD",		scrollback_backwards },
 	{ "SCROLL_END",			scrollback_end },
 	{ "SCROLL_FORWARD",		scrollback_forwards },
+	{ "SCROLL_START",		scrollback_start },
 	{ "SELF_INSERT",		input_add_character },
 	{ "SEND_LINE",			send_line },
 	{ "STOP_IRC",			term_pause },
@@ -761,9 +763,9 @@ KeyMap	keys[] =
 	{ SELF_INSERT,		0,	null(char *) },
 	{ SELF_INSERT,		0,	null(char *) },
 	{ SELF_INSERT,		0,	null(char *) },
+	{ SCROLL_START,		0,	null(char *) },
 	{ SELF_INSERT,		0,	null(char *) },
-	{ SELF_INSERT,		0,	null(char *) },
-	{ SELF_INSERT,		0,	null(char *) },
+	{ SCROLL_END,		0,	null(char *) },
 	{ SELF_INSERT,		0,	null(char *) },
 
 	{ SELF_INSERT,		0,	null(char *) },	/* 192 */
@@ -804,14 +806,14 @@ KeyMap	keys[] =
 
 	{ SELF_INSERT,		0,	null(char *) },	/* 224 */
 	{ SELF_INSERT,		0,	null(char *) },
+	{ BACKWARD_WORD,	0,	null(char *) },
 	{ SELF_INSERT,		0,	null(char *) },
-	{ SELF_INSERT,		0,	null(char *) },
-	{ SELF_INSERT,		0,	null(char *) },
-	{ SELF_INSERT,		0,	null(char *) },
-	{ SELF_INSERT,		0,	null(char *) },
+	{ DELETE_NEXT_WORD,	0,	null(char *) },
+	{ SCROLL_END,		0,	null(char *) },
+	{ FORWARD_WORD,		0,	null(char *) },
 	{ SELF_INSERT,		0,	null(char *) },
 
-	{ SELF_INSERT,		0,	null(char *) },	/* 232 */
+	{ DELETE_PREVIOUS_WORD,	0,	null(char *) },	/* 232 */
 	{ SELF_INSERT,		0,	null(char *) },
 	{ SELF_INSERT,		0,	null(char *) },
 	{ SELF_INSERT,		0,	null(char *) },
@@ -836,7 +838,7 @@ KeyMap	keys[] =
 	{ SELF_INSERT,		0,	null(char *) },
 	{ SELF_INSERT,		0,	null(char *) },
 	{ SELF_INSERT,		0,	null(char *) },
-	{ SELF_INSERT,		0,	null(char *) }
+	{ DELETE_PREVIOUS_WORD,	0,	null(char *) }
 };
 
 
@@ -909,9 +911,9 @@ KeyMap	meta1_keys[] =
 	{ NOTHING,		0,	null(char *) },
 	{ NOTHING,		0,	null(char *) },
 	{ NOTHING,		0,	null(char *) },
+	{ SCROLL_START,		0,	null(char *) },
 	{ NOTHING,		0,	null(char *) },
-	{ NOTHING,		0,	null(char *) },
-	{ NOTHING,		0,	null(char *) },
+	{ SCROLL_END,		0,	null(char *) },
 	{ NOTHING,		0,	null(char *) },
 
 	{ NOTHING,		0,	null(char *) },	/* 64 */
@@ -952,7 +954,7 @@ KeyMap	meta1_keys[] =
 
 	{ NOTHING,		0,	null(char *) },	/* 96 */
 	{ NOTHING,		0,	null(char *) },
-	{ BACKWARD_WORD,		0,	null(char *) },
+	{ BACKWARD_WORD,	0,	null(char *) },
 	{ NOTHING,		0,	null(char *) },
 	{ DELETE_NEXT_WORD,	0,	null(char *) },
 	{ SCROLL_END,		0,	null(char *) },
@@ -965,7 +967,7 @@ KeyMap	meta1_keys[] =
 	{ NOTHING,		0,	null(char *) },
 	{ NOTHING,		0,	null(char *) },
 	{ NOTHING,		0,	null(char *) },
-	{ SCROLL_FORWARD,		0,	null(char *) },
+	{ SCROLL_FORWARD,	0,	null(char *) },
 	{ NOTHING,		0,	null(char *) },
 
 	{ SCROLL_BACKWARD,	0,	null(char *) },	/* 112 */
@@ -984,7 +986,7 @@ KeyMap	meta1_keys[] =
 	{ NOTHING,		0,	null(char *) },
 	{ NOTHING,		0,	null(char *) },
 	{ NOTHING,		0,	null(char *) },
-	{ NOTHING,		0,	null(char *) },
+	{ DELETE_PREVIOUS_WORD,	0,	null(char *) },
 
 	{ NOTHING,		0,	null(char *) },	/* 128 */
 	{ NOTHING,		0,	null(char *) },
