@@ -325,7 +325,6 @@ char	**ArgList;
 	char	*user;
 	char	none_of_these = 0;
 	char	blah[BIG_BUFFER_SIZE];
-	static	int	not = 0;
 	int	flag,
 		lastlog_level;
 #if 0
@@ -351,9 +350,8 @@ char	**ArgList;
 	case 002:	/* #define RPL_YOURHOST         002 */
 		PasteArgs(ArgList, 0);
 		flag = do_hook(current_numeric, "%s %s", from, *ArgList);
-		sprintf(blah, "%s %s", numeric_banner(), ArgList[0]);
-		if (!not)
-			got_initial_version(blah);
+		sprintf(blah, "*** %s", ArgList[0]);
+		got_initial_version(blah);
 		if (flag)
 			display_msg(from, ArgList);
 		break;
@@ -462,15 +460,21 @@ char	**ArgList;
 		break;
 
 	case 366:		/* #define RPL_ENDOFNAMES       366 */
-		if (!funny_is_ignore_channel())
 		{
+			int	flag;
+
 			PasteArgs(ArgList, 0);
-			if (do_hook(current_numeric, "%s %s", from, ArgList[0]))
-				if (get_int_var(SHOW_END_OF_MSGS_VAR))
+			flag = do_hook(current_numeric, "%s %s", from,
+				ArgList[0]);
+		
+			if (!funny_is_ignore_channel())
+			{
+				if (get_int_var(SHOW_END_OF_MSGS_VAR) && flag)
 					display_msg(from, ArgList);
+			}
+			else
+				funny_set_ignore_mode();
 		}
-		else
-			funny_set_ignore_mode();
 		break;
 
 	case 381: 		/* #define RPL_YOUREOPER        381 */
