@@ -153,19 +153,6 @@ char	**OutPut;
 	OutPut[ArgCount] = NULL;
 }
 
-int	IgnoreCombo(flag1, flag2)
-int	flag1;
-int	flag2;
-{
-	if (flag1 == DONT_IGNORE || flag2 == DONT_IGNORE)
-		return DONT_IGNORE;
-	if (flag1 == IGNORED || flag2 == IGNORED)
-		return IGNORED;
-	if (flag1 == HIGHLIGHTED || flag2 == HIGHLIGHTED)
-		return HIGHLIGHTED;
-	return 0;
-}
-
 /* beep_em: Not hard to figure this one out */
 void	beep_em(beeps)
 int	beeps;
@@ -182,15 +169,9 @@ static	void	topic(from, ArgList)
 char	*from,
 	**ArgList;
 {
-	int	flag,
-		flag2;
+	int	flag;
 
-	flag = is_ignored(from, IGNORE_CRAP);
-	if (FromUserHost)
-	{
-		flag2 = is_ignored(FromUserHost, IGNORE_CRAP);
-		flag = IgnoreCombo(flag, flag2);
-	}
+	flag = double_ignore(from, FromUserHost, IGNORE_CRAP);
 	if (flag == IGNORED)
 		return;
 
@@ -216,12 +197,11 @@ char	**ArgList;
 	say("%s", ArgList[0]);
 }
 
-static	void	wall(from, ArgList)
+static	void	p_wall(from, ArgList)
 char	*from,
 	**ArgList;
 {
 	int	flag,
-		flag2,
 		level;
 	char	*line;
 	char	*high;
@@ -229,13 +209,8 @@ char	*from,
 	PasteArgs(ArgList, 0);
 	if (!(line = ArgList[0]))
 		return;
+	flag = double_ignore(from, FromUserHost, IGNORE_WALLS);
 	message_from(from, LOG_WALL);
-	flag = is_ignored(from, IGNORE_WALLS);
-	if (FromUserHost)
-	{
-		flag2 = is_ignored(FromUserHost, IGNORE_WALLS);
-		flag = IgnoreCombo(flag, flag2);
-	}
 	if (flag != IGNORED)
 	{
 		if (flag == HIGHLIGHTED)
@@ -263,18 +238,12 @@ static	void	wallops(from, ArgList)
 char	*from,
 	**ArgList;
 {
-	int	flag,
-		flag2;
+	int	flag;
 	char	*line;
 
 	if (!(line = PasteArgs(ArgList, 0)))
 		return;
-	flag = is_ignored(from, IGNORE_WALLOPS);
-	if (FromUserHost)
-	{
-		flag2 = is_ignored(FromUserHost, IGNORE_WALLOPS);
-		flag = IgnoreCombo(flag, flag2);
-	}
+	flag = double_ignore(from, FromUserHost, IGNORE_WALLOPS);
 	if (index(from, '.'))
 	{
 	/* The old server check, don't use the whois stuff for servers */
@@ -420,13 +389,12 @@ char	**ArgList,
 	}
 }
 
-static	void	privmsg(from, Args)
+static	void	p_privmsg(from, Args)
 char	*from,
 	**Args;
 {
 	int	level,
 		flag,
-		flag2,
 		list_type,
 		flood_type,
 		log_type;
@@ -480,12 +448,7 @@ char	*from,
 			list_type = MSG_LIST;
 		}
 	}
-	flag = is_ignored(from, ignore_type);
-	if (FromUserHost)
-	{
-		flag2 = is_ignored(FromUserHost, ignore_type);
-		flag = IgnoreCombo(flag, flag2);
-	}
+	flag = double_ignore(from, FromUserHost, ignore_type);
 	switch (flag)
 	{
 	case IGNORED:
@@ -501,7 +464,7 @@ char	*from,
 		break;
 	}
 	ptr = do_ctcp(from, to, ptr);
-	if (*ptr == null(char))
+	if (!*ptr)
 		return;
 	level = set_lastlog_msg_level(log_type);
 	if ((flag != DONT_IGNORE) && (ignore_usernames & ignore_type) &&
@@ -523,32 +486,29 @@ char	*from,
 			    put_it("%s-%s:%s-%s %s", high, from, to, high, ptr);
 			break;
 		case MSG_LIST:
+			if (!no_flood)
+				break;
 			malloc_strcpy(&recv_nick, from);
-			if (away_set)
+			if (do_hook(list_type, "%s %s", from, ptr))
 			{
+			    if (away_set)
+			    {
 #ifdef ultrix
 				time_t t;
-#else
+#else /* ultrix */
 				Long t;
-#endif
+#endif /* ultrix */
 				char *msg = null(char *);
 
-				t = time(0);
+				t = time(NULL);
 				msg = (char *) new_malloc(strlen(ptr) + 20);
 				sprintf(msg, "%s <%.16s>", ptr, ctime(&t));
-				if (no_flood && do_hook(list_type, "%s %s",
-						from, msg))
-					put_it("%s*%s*%s %s", high, from,
-							high, msg);
+				put_it("%s*%s*%s %s", high, from, high, msg);
 				new_free(&msg);
 				beep_em(get_int_var(BEEP_WHEN_AWAY_VAR));
-			}
-			else
-			{
-				if (no_flood && do_hook(list_type, "%s %s",
-						from, ptr))
-					put_it("%s*%s*%s %s", high, from,
-							high, ptr);
+			    }
+			    else
+				put_it("%s*%s*%s %s", high, from, high, ptr);
 			}
 			break;
 		case PUBLIC_LIST:
@@ -584,14 +544,8 @@ char	*from,
 	int	log_type,
 		no_flooding;
 	int	flag;
-	int	flag2;
 
-	flag = is_ignored(from, IGNORE_PUBLIC);
-	if (FromUserHost)
-	{
-		flag2=is_ignored(FromUserHost, IGNORE_PUBLIC);
-		flag = IgnoreCombo(flag, flag2);
-	}
+	flag = double_ignore(from, FromUserHost, IGNORE_PUBLIC);
 	switch (flag)
 	{
 	case IGNORED:
@@ -634,22 +588,16 @@ char	*from,
 }
 
 /*ARGSUSED*/
-static	void	quit(from, ArgList)
+static	void	p_quit(from, ArgList)
 char	*from,
 	**ArgList;
 {
 	int	one_prints = 0;
 	char	*chan;
 	char	*Reason;
-	int	flag,
-		flag2;
+	int	flag;
 
-	flag = is_ignored(from, IGNORE_CRAP);
-	if (FromUserHost)
-	{
-		flag2 = is_ignored(FromUserHost, IGNORE_CRAP);
-		flag = IgnoreCombo(flag, flag2);
-	}
+	flag = double_ignore(from, FromUserHost, IGNORE_CRAP);
 	if (flag != IGNORED)
 	{
 		PasteArgs(ArgList, 0);
@@ -677,15 +625,9 @@ static	void	pong(from, ArgList)
 char	*from,
 	**ArgList;
 {
-	int	flag,
-		flag2;
+	int	flag;
 
-	flag = is_ignored(from, IGNORE_CRAP);
-	if (FromUserHost)
-	{
-		flag2 = is_ignored(FromUserHost, IGNORE_CRAP);
-		flag = IgnoreCombo(flag, flag2);
-	}
+	flag = double_ignore(from, FromUserHost, IGNORE_CRAP);
 	if (flag == IGNORED)
 		return;
 
@@ -704,21 +646,15 @@ char	*from,
 	say("%s", ArgList[0]);
 }
 
-static	void	channel(from, ArgList)
+static	void	p_channel(from, ArgList)
 char	*from;
 char	**ArgList;
 {
 	int	join;
 	char	*channel;
-	int	flag,
-		flag2;
+	int	flag;
 
-	flag = is_ignored(from, IGNORE_CRAP);
-	if (FromUserHost)
-	{
-		flag2 = is_ignored(FromUserHost, IGNORE_CRAP);
-		flag = IgnoreCombo(flag, flag2);
-	}
+	flag = double_ignore(from, FromUserHost, IGNORE_CRAP);
 	if (strcmp(ArgList[0], "0"))
 	{
 		join = 1;
@@ -773,20 +709,14 @@ char	**ArgList;
 	}
 }
 
-static	void	invite(from, ArgList)
+static	void	p_invite(from, ArgList)
 char	*from,
 	**ArgList;
 {
 	char	*high;
-	int	flag,
-		flag2;
+	int	flag;
 
-	flag = is_ignored(from, IGNORE_INVITES);
-	if (FromUserHost)
-	{
-		flag2 = is_ignored(FromUserHost, IGNORE_INVITES);
-		flag = IgnoreCombo(flag, flag2);
-	}
+	flag = double_ignore(from, FromUserHost, IGNORE_INVITES);
 	switch (flag)
 	{
 	case IGNORED:
@@ -853,7 +783,7 @@ char	*from,
 	{
 		say("You have been killed by operator %s %s", from,
 			ArgList[1] ? ArgList[1] : "(No Reason Given)");
-#if !defined(NO_QUIT_ON_OPERATOR_KILL) && !defined(PHONE)
+#ifndef NO_QUIT_ON_OPERATOR_KILL
 			irc_exit();
 #endif /* NO_QUIT_ON_OPERATOR_KILL */
 		if (background)
@@ -870,27 +800,23 @@ char	**ArgList;
 	send_to_server("PONG %s@%s %s", username, hostname, ArgList[0]);
 }
 
-static	void	nick(from, ArgList)
+static	void	p_nick(from, ArgList)
 char	*from,
 	**ArgList;
 {
-	int	one_prints = 0;
+	int	one_prints = 0,
+		its_me = 0;
 	char	*chan;
 	char	*line;
-	int	flag,
-		flag2;
+	int	flag;
 
-	flag = is_ignored(from, IGNORE_CRAP);
-	if (FromUserHost)
-	{
-		flag2 = is_ignored(FromUserHost, IGNORE_CRAP);
-		flag = IgnoreCombo(flag, flag2);
-	}
+	flag = double_ignore(from, FromUserHost, IGNORE_CRAP);
 	line = ArgList[0];
 	if (stricmp(from, get_server_nickname(from_server)) == 0){
 		if (from_server == primary_server)
 			strmcpy(nickname, line, NICKNAME_LEN);
 		set_server_nickname(from_server, line);
+		its_me = 1;
 	}
 	if (flag != IGNORED)
 	{
@@ -903,7 +829,10 @@ char	*from,
 		}
 		if (one_prints)
 		{
-			message_from(what_channel(from), LOG_CRAP);
+			if (its_me)
+				message_from(NULL, LOG_CRAP);
+			else
+				message_from(what_channel(from), LOG_CRAP);
 			if (do_hook(NICKNAME_LIST, "%s %s", from, line))
 				say("%s is now known as %s", from, line);
 		}
@@ -917,16 +846,9 @@ char	*from,
 {
 	char	*channel;
 	char	*line;
-	int	flag,
-		flag2;
-
-	flag = is_ignored(from, IGNORE_CRAP);
-	if (FromUserHost)
-	{
-		flag2 = is_ignored(FromUserHost, IGNORE_CRAP);
-		flag = IgnoreCombo(flag, flag2);
-	}
+	int	flag;
 
+	flag = double_ignore(from, FromUserHost, IGNORE_CRAP);
 	PasteArgs(ArgList, 1);
 	channel = ArgList[0];
 	line = ArgList[1];
@@ -1005,15 +927,9 @@ char	*from,
 	**ArgList;
 {
 	char	*channel;
-	int	flag,
-		flag2;
+	int	flag;
 
-	flag = is_ignored(from, IGNORE_CRAP);
-	if (FromUserHost)
-	{
-		flag2 = is_ignored(FromUserHost, IGNORE_CRAP);
-		flag = IgnoreCombo(flag, flag2);
-	}
+	flag = double_ignore(from, FromUserHost, IGNORE_CRAP);
 	channel = ArgList[0];
 	message_from(channel, LOG_CRAP);
 	in_on_who = 1;
@@ -1069,22 +985,22 @@ char	*line;
 	else if (strcmp(comm, "NOTICE") == 0)
 		parse_notice(from, ArgList);
 	else if (strcmp(comm, "PRIVMSG") == 0)
-		privmsg(from, ArgList);
+		p_privmsg(from, ArgList);
 	else if (strcmp(comm, "NAMREPLY") == 0)
 		funny_namreply(from, ArgList);
 	else if (strcmp(comm, "JOIN") == 0)
-		channel(from, ArgList);
+		p_channel(from, ArgList);
 	else if (strcmp(comm, "PART") == 0)
 		part(from, ArgList);
 		/* CHANNEL will go away with 2.6 */
 	else if (strcmp(comm, "CHANNEL") == 0)
-		channel(from, ArgList);
+		p_channel(from, ArgList);
 	else if (strcmp(comm, "MSG") == 0)
 		msg(from, ArgList);
 	else if (strcmp(comm, "QUIT") == 0)
-		quit(from, ArgList);
+		p_quit(from, ArgList);
 	else if (strcmp(comm, "WALL") == 0)
-		wall(from, ArgList);
+		p_wall(from, ArgList);
 	else if (strcmp(comm, "WALLOPS") == 0)
 		wallops(from, ArgList);
 	else if (strcmp(comm, "LINREPLY") == 0)
@@ -1096,9 +1012,9 @@ char	*line;
 	else if (strcmp(comm, "PONG") == 0)
 		pong(from, ArgList);
 	else if (strcmp(comm, "INVITE") == 0)
-		invite(from, ArgList);
+		p_invite(from, ArgList);
 	else if (strcmp(comm, "NICK") == 0)
-		nick(from, ArgList);
+		p_nick(from, ArgList);
 	else if (strcmp(comm, "KILL") == 0)
 		server_kill(from, ArgList);
 	else if (strcmp(comm, "MODE") == 0)
