@@ -9,12 +9,13 @@
  * See the COPYRIGHT file, or do a HELP IRCII COPYRIGHT 
  */
 #include <stdio.h>
-/* #include <values.h> */
 #include <sys/types.h>
 #include <sys/time.h>
 #include <sys/socket.h>
 #include <signal.h>
+/*			gets included in dcc.h 
 #include <netinet/in.h>
+*/
 #include <sys/un.h>
 #include <ctype.h>
 #include "irc.h"
@@ -50,7 +51,7 @@ extern	int	in_help;	/* Used to suppress holding of help text */
 extern	char	*redirect_nick;
 
 /* Our list of screens */
-Screen	*screen_list = null(Screen *);
+Screen	*screen_list = NULL;
 
 static	void	display_lastlog_lines();
 extern	void	close_all_server();
@@ -62,7 +63,7 @@ extern	void	close_all_server();
  */
 Screen	*create_new_screen()
 {
-	Screen	*new = null(Screen *),
+	Screen	*new = NULL,
 		**list;
 	static	int	refnumber = 0;
 
@@ -84,12 +85,12 @@ Screen	*create_new_screen()
 		screen_list = new;
 	}
 	new->last_window_refnum = 1;
-	new->window_list = null(Window *);
-	new->window_list_end = null(Window *);
-	new->cursor_window = null(Window *);
-	new->current_window = null(Window *);
+	new->window_list = NULL;
+	new->window_list_end = NULL;
+	new->cursor_window = NULL;
+	new->current_window = NULL;
 	new->visible_windows = 0;
-	new->window_stack = null(WindowStack *);
+	new->window_stack = NULL;
 	new->meta1_hit = new->meta2_hit = new->meta3_hit = new->meta4_hit = 0;
 	new->quote_hit = new->digraph_hit = new->inside_menu = 0;
 	new->buffer_pos = new->buffer_min_pos = 0;
@@ -99,9 +100,9 @@ Screen	*create_new_screen()
 	new->fdin = 0;
 	new->fpin = stdin;
 	new->alive = 1;
-	new->promptlist = null(WaitPrompt *);
-	new->redirect_name = null(char *);
-	new->redirect_token = null(char *);
+	new->promptlist = NULL;
+	new->redirect_name = NULL;
+	new->redirect_token = NULL;
 	new->redirect_server = -1;
 	last_input_screen = new;
 	return new;
@@ -124,13 +125,13 @@ int	type;
 		   *New;
 
 	New = (WaitPrompt *) new_malloc(sizeof(WaitPrompt));
-	New->prompt = null(char *);
+	New->prompt = NULL;
 	malloc_strcpy(&New->prompt, prompt);
-	New->data = null(char *);
+	New->data = NULL;
 	malloc_strcpy(&New->data, data);
 	New->type = type;
 	New->func = func;
-	New->next = null(WaitPrompt *);
+	New->next = NULL;
 	for (AddLoc = &current_screen->promptlist; *AddLoc;
 			AddLoc = &(*AddLoc)->next);
 	*AddLoc = New;
@@ -178,7 +179,7 @@ char	*nick;
 		{
 			tmp_screen = current_screen;
 			current_screen = screen;
-			window_redirect(null(char *), from_server);
+			window_redirect(NULL, from_server);
 			current_screen = tmp_screen;
 			return 1;
 		}
@@ -411,7 +412,7 @@ int	flag;
 
 /*
  * output_line prints the given string at the current screen position,
- * performing adjustments for ^B, ^V, and ^O
+ * performing adjustments for ^_, ^B, ^V, and ^O
  */
 int	output_line(str, result, startpos)
 char	*str;
@@ -419,14 +420,14 @@ char	**result;
 int	startpos;
 {
 	static	int	high = OFF, bold = OFF;
-	int	rev_tog, und_tog, bld_tog, both_off;
+	int	rev_tog, und_tog, bld_tog, all_off;
 	char	*ptr;
 	int	len;
 	int	written = 0;
 	char	c;
 	char	*original;
 
-	original=str;
+	original = str;
 	ptr = str;
 	display_highlight(high);
 	display_bold(bold);
@@ -443,42 +444,40 @@ int	startpos;
 			written += len;
 			if (startpos)
 			{
-				if (ptr-original>startpos)
+				if (ptr - original > startpos)
 				{
-					str+=len-(ptr-original-startpos);
-					len=ptr-original-startpos;
-					startpos=0;
+					str += len - (ptr - original - startpos);
+					len = ptr - original - startpos;
+					startpos = 0;
 				}
 			}
 			if (written > CO)
 				len = len - (written - CO);
 			if (!startpos)
-			{
 				fwrite(str, len, 1, current_screen->fpout);
-			}
-			rev_tog = und_tog = bld_tog = both_off = 0;
+			rev_tog = und_tog = bld_tog = all_off = 0;
 			do
 			{
 				switch(*ptr)
 
 				{
 				case REV_TOG:
-					rev_tog = (!rev_tog);
+					rev_tog = 1 - rev_tog;
 					break;
 				case UND_TOG:
-					und_tog = (!und_tog);
+					und_tog = 1 - und_tog;
 					break;
 				case BOLD_TOG:
-					bld_tog = (!bld_tog);
+					bld_tog = 1 - bld_tog;
 					break;
 				case ALL_OFF:
-					both_off = 1;
+					all_off = 1;
 					und_tog = rev_tog = bld_tog = 0;
 					break;
 				}
 			} while ((ptr[1] == REV_TOG || ptr[1] == UND_TOG ||
 			    ptr[1] == BOLD_TOG || ptr[1] == ALL_OFF) && ptr++);
-			if (both_off)
+			if (all_off)
 			{
 				if (!underline)
 				{
@@ -504,7 +503,7 @@ int	startpos;
 			}
 			if (bld_tog)
 			{
-				display_bold(TOGGLE);
+				bold = display_bold(TOGGLE);
 				bold = 1 - bold;
 			}
 			str = ++ptr;
@@ -515,24 +514,22 @@ int	startpos;
 		 * so far, we beep the terminal 
 		 */
 			c = *ptr;
-			*ptr = null(char);
+			*ptr = '\0';
 			len = strlen(str);
 			written += len;
 			if (startpos)
 			{
-				if (ptr-original>startpos)
+				if (ptr - original > startpos)
 				{
-					str+=len-(ptr-original-startpos);
-					len=ptr-original-startpos;
-					startpos=0;
+					str += len - (ptr - original - startpos);
+					len = ptr - original - startpos;
+					startpos = 0;
 				}
 			}
 			if (written > CO)
 				len = len - (written - CO);
 			if (!startpos)
-			{
 				fwrite(str, len, 1, current_screen->fpout);
-			}
 			term_beep();
 			*ptr = c;
 			str = ++ptr;
@@ -703,7 +700,7 @@ int	show,
  */
 void	cursor_not_in_display()
 {
-	current_screen->cursor_window = null(Window *);
+	current_screen->cursor_window = NULL;
 }
 
 /*
@@ -775,10 +772,10 @@ Window	*window;
 	{
 		return Result;
 	}
-	if (window->top_of_display == null(Display *))
+	if (!window->top_of_display)
 	{
 		window->top_of_display = (Display *)new_malloc(sizeof(Display));
-		window->top_of_display->line = null(char *);
+		window->top_of_display->line = NULL;
 		window->top_of_display->linetype = LT_UNLOGGED;
 		window->top_of_display->next = window->top_of_display;
 		window->display_ip = window->top_of_display;
@@ -788,7 +785,7 @@ Window	*window;
 	cnt = window->display_size - window->old_size;
 	if (cnt > 0)
 	{
-		Display *new = null(Display *);
+		Display *new = NULL;
 
 	/*
 	 * screen got bigger: got to last display entry and link in new
@@ -800,7 +797,7 @@ Window	*window;
 		for (i = 0; i < cnt; i++)
 		{
 			new = (Display *) new_malloc(sizeof(Display));
-			new->line = null(char *);
+			new->line = NULL;
 			new->linetype = LT_UNLOGGED;
 			new->next = tmp->next;
 			tmp->next = new;
@@ -910,7 +907,7 @@ Window	*window;
 
 	if (dumb)
 		return;
-	if (window == null(Window *))
+	if (window == NULL)
 		window = curr_scr_win;
 	erase_display(window);
 	term_move_cursor(0, window->top + window->menu.lines);
@@ -953,8 +950,7 @@ int	just_one;
 
 	if (dumb || !window->visible)
 		return;
-	if (window == null(Window *))
-		window = curr_scr_win;
+	window = window ? window : curr_scr_win;
 	if (just_one < 0)
 
 	{
@@ -1042,22 +1038,22 @@ char	*str;
 {
 	static	char	*output[MAXIMUM_SPLITS] =
 	{ 
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *)
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL
 	};
 	char	buffer[BIG_BUFFER_SIZE + 1];
 	unsigned char *ptr;
 	char	*cont_ptr,
-		*cont = null(char *),
-		*temp = null(char *),
+		*cont = NULL,
+		*temp = NULL,
 		c;
 	int	pos = 0,
 		col = 0,
@@ -1076,7 +1072,7 @@ char	*str;
 	for (i = 0; i < BIG_BUFFER_SIZE + 1; ++i) buffer[i] = '\0';
 	for (i = 0; i < MAXIMUM_SPLITS; i++)
 		new_free(&output[i]);
-	if (*str == null(char))
+	if (!*str)
 		str = " ";	/* special case to make blank lines show up */
 
 	beep_max = get_int_var(BEEP_VAR) ? get_int_var(BEEP_MAX_VAR) : -1;
@@ -1159,14 +1155,14 @@ char	*str;
 			col++;
 		}
 		if (pos == BIG_BUFFER_SIZE)
-			*ptr = null(char);
+			*ptr = '\0';
 		if (col >= CO)
 		{
 			/* one big long line, no word breaks */
 			if (word_break == 0)
 				word_break = pos - (col - CO);
 			c = buffer[word_break];
-			buffer[word_break] = null(char);
+			buffer[word_break] = '\0';
 			if (cont)
 			{
 				malloc_strcpy(&temp, cont);
@@ -1182,8 +1178,8 @@ char	*str;
 				start++;
 			if (start > pos)
 				start = pos;
-			if ((cont_ptr = get_string_var(CONTINUED_LINE_VAR))
-					== null(char *))
+			if (!(cont_ptr = get_string_var(CONTINUED_LINE_VAR)))
+					
 				cont_ptr = empty_string;
 			if (get_int_var(INDENT_VAR) && (indent < CO / 3))
 			{
@@ -1191,7 +1187,7 @@ char	*str;
 		 * INDENT thanks to Carlo "lynx" v. Loesch
 		 * - hehe, nice to see this is still here... -lynx 91
 		 */
-				if (cont == null(char *))
+				if (!cont)
 				{
 					if ((len = strlen(cont_ptr)) > indent)
 					{
@@ -1206,7 +1202,7 @@ char	*str;
 						strcpy(cont, cont_ptr);
 						for (i = len; i < indent; i++)
 							cont[i] = ' ';
-						cont[indent] = null(char);
+						cont[indent] = '\0';
 					}
 				}
 			}
@@ -1215,7 +1211,7 @@ char	*str;
 			col = strlen(cont) + (pos - start);
 		}
 	}
-	buffer[pos] = null(char);
+	buffer[pos] = '\0';
 	if (buffer[start])
 	{
 		if (cont)
@@ -1259,7 +1255,7 @@ char	*str;
 
 		display_highlight(OFF);
 		display_bold(OFF);
-		strmcat(str, global_all_off, 1);
+		strmcat(str, global_all_off, BIG_BUFFER_SIZE - 1);
 		logged = islogged(window);
 		for (lines = split_up_line(str); *lines; lines++)
 		{
@@ -1390,7 +1386,7 @@ char	*buffer;
 			if (tmp->server == from_server)
 				break;
 		}
-		if (tmp == null(Window *))
+		if (!tmp)
 			tmp = curr_scr_win;
 	}
 	add_to_window(tmp, buffer);
@@ -1491,7 +1487,7 @@ Window	*new_window()
 		no_screens = 0;
 	}
 	if (dumb && (current_screen->visible_windows == 1))
-		return (null(Window *));
+		return NULL;
 	new = (Window *) new_malloc(sizeof(Window));
 	new->refnum = create_refnum();
 	if (curr_scr_win)
@@ -1507,41 +1503,41 @@ Window	*new_window()
 		new->window_level = LOG_NONE;
 	new->hold_mode = get_int_var(HOLD_MODE_VAR);
 	new->scroll = get_int_var(SCROLL_VAR);
-	new->lastlog_head = null(Lastlog *);
-	new->lastlog_tail = null(Lastlog *);
-	new->nicks = null(NickList *);
+	new->lastlog_head = NULL;
+	new->lastlog_tail = NULL;
+	new->nicks = NULL;
 	new->lastlog_level = real_lastlog_level();
-	new->name = null(char *);
-	new->prompt = null(char *);
+	new->name = NULL;
+	new->prompt = NULL;
 	new->lastlog_size = 0;
 	new->held = OFF;
 	new->last_held = OFF;
-	new->current_channel = null(char *);
-	new->query_nick = null(char *);
+	new->current_channel = NULL;
+	new->query_nick = NULL;
 	new->hold_on_next_rite = 0;
-	new->status_line = null(char *);
-	new->top_of_display = null(Display *);
-	new->display_ip = null(Display *);
+	new->status_line = NULL;
+	new->top_of_display = NULL;
+	new->display_ip = NULL;
 	new->display_size = 1;
 	new->old_size = 1;
-	new->hold_head = null(Hold *);
-	new->hold_tail = null(Hold *);
+	new->hold_head = NULL;
+	new->hold_tail = NULL;
 	new->held_lines = 0;
 	new->scrolled_lines = 0;
 	new->new_scrolled_lines = 0;
-	new->next = null(Window *);
-	new->prev = null(Window *);
+	new->next = NULL;
+	new->prev = NULL;
 	new->cursor = 0;
 	new->visible = 1;
 	new->screen = current_screen;
-	new->waiting_channel = null(char *);
-	new->logfile = null(char *);
+	new->waiting_channel = NULL;
+	new->logfile = NULL;
 	new->log = 0;
-	new->log_fp = null(FILE *);
+	new->log_fp = NULL;
 	new->miscflags = 0;
 	new->update = 0;
 	new->menu.lines = 0;
-	new->menu.menu = null(Menu *);
+	new->menu.menu = NULL;
 	new->notify_level = real_notify_level();
 	resize_display(new);
 	if (add_to_window_list(new))
@@ -1636,7 +1632,7 @@ extern	Window	*create_additional_screen()
 				*args[64],
 				*s,
 				*t,
-				*opts = null(char *);
+				*opts = NULL;
 
 			copy_window_size(&lines, &columns);
 			sprintf(geom, "%dx%d", columns, lines);
@@ -1664,7 +1660,7 @@ extern	Window	*create_additional_screen()
 	FD_ZERO(&fd_read);
 	FD_SET(s, &fd_read);
 	timeout.tv_sec = (Long) 5;
-	switch (select(NFDBITS , &fd_read, null(fd_set *), null(fd_set *),
+	switch (select(NFDBITS , &fd_read, NULL, NULL,
 			&timeout))
 	{
 	case -1:
@@ -1673,7 +1669,7 @@ extern	Window	*create_additional_screen()
 		kill(child, SIGKILL);
 		last_input_screen = oldscreen;
 		set_current_screen(oldscreen);
-		return null(Window *);
+		return NULL;
 		break;
 	case 1:
 		current_screen->fdin = current_screen->fdout =
@@ -1683,7 +1679,7 @@ extern	Window	*create_additional_screen()
 		close(s);
 		unlink(sockaddr->sun_path);
 		win = new_window();
-		(void) refresh_screen(0, null(char *));
+		(void) refresh_screen(0, NULL);
 		set_current_screen(oldscreen);
 		return win;
 		break;
@@ -1700,16 +1696,16 @@ Window	*window;
 	char	**TheirLines;
 	static	char	*ScreenLines[MAXIMUM_SPLITS] =
 	{ 
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *),
-		null(char *), null(char *), null(char *), null(char *)
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL,
+		NULL, NULL, NULL, NULL
 	};
 
 	if (window)
@@ -1724,7 +1720,7 @@ Window	*window;
 		if (!window && LogLine)
 			LogLine = LogLine->next;
 		if (!LogLine)
-			return null(char *);
+			return NULL;
 		TheirLines = split_up_line(LogLine->msg);
 		for (row = 0; TheirLines[row]; row++)
 		{
@@ -1746,22 +1742,22 @@ Window	*window;
 	char	*Line;
 	int	i;
 
-	next_line_back(window);
+	(void)next_line_back(window);
 
 	for (i = window->new_scrolled_lines; i--;)
-		next_line_back(NULL);
+		(void)next_line_back(NULL);
 
 	for (i = 0, Disp = window->top_of_display; i < window->display_size;
 			Disp = Disp->next, i++)
 		if (Disp->linetype)
-			next_line_back(null(Window *));
+			(void)next_line_back(NULL);
 
 	for (i = 0; i < start; i++)
-		next_line_back(null(Window *));
+		(void)next_line_back(NULL);
 
 	for (; i < end; i++)
 	{
-		if (!(Line = next_line_back(null(Window *))))
+		if (!(Line = next_line_back(NULL)))
 			break;
 		term_move_cursor(0, window->top + window->menu.lines +
 			window->scrolled_lines - i - 1);
@@ -1824,10 +1820,10 @@ int	ScrollDist;
 	if (!window->scrolled_lines)
 	{
 		window->new_scrolled_lines = 0;
-		if (curr_scr_win->hold_mode)
-			hold_mode(curr_scr_win, ON, 1);
+		if (window->hold_mode)
+			hold_mode(window, ON, 1);
 		else
-			hold_mode(curr_scr_win, OFF, 0);
+			hold_mode(window, OFF, 0);
 	}
 }
 
@@ -1844,23 +1840,60 @@ extern	void	scrollback_backwards()
 
 extern	void	scrollback_end()
 {
-	curr_scr_win->new_scrolled_lines = 0;
-	if (!curr_scr_win->scrolled_lines)
+	Window	*window;
+
+	window = curr_scr_win;
+	window->new_scrolled_lines = 0;
+
+	if (!window->scrolled_lines)
 	{
 		term_beep();
 		return;
 	}
-	if (curr_scr_win->scrolled_lines < curr_scr_win->display_size)
-		scrollback_forwards_lines(curr_scr_win->scrolled_lines);
+	if (window->scrolled_lines < window->display_size)
+		scrollback_forwards_lines(window->scrolled_lines);
 	else
 	{
-		curr_scr_win->scrolled_lines = 0;
-		redraw_window(curr_scr_win, 1);
+		window->scrolled_lines = 0;
+		redraw_window(window, 1);
 		cursor_not_in_display();
 		update_input(UPDATE_JUST_CURSOR);
-		if (curr_scr_win->hold_mode)
-			hold_mode(curr_scr_win, ON, 1);
+		if (window->hold_mode)
+			hold_mode(window, ON, 1);
 		else
-			hold_mode(curr_scr_win, OFF, 0);
+			hold_mode(window, OFF, 0);
+	}
+}
+
+/*
+ * scrollback_start: moves the current screen back to the start of
+ * the scrollback buffer..  there are probably cases this doesn't
+ * quite work.. -phone, april 1993.
+ */
+extern	void	scrollback_start()
+{
+	Window	*window;
+
+	window = curr_scr_win;
+	if (!window->lastlog_size)
+	{
+		term_beep();
+		return;
+	}
+
+	if (window->lastlog_size < window->display_size)
+		scrollback_backwards_lines(window->lastlog_size);
+	else
+	{
+		window->scrolled_lines = window->lastlog_size;
+		display_lastlog_lines(window->scrolled_lines -
+			window->display_size, window->scrolled_lines, window);
+		cursor_not_in_display();
+		update_input(UPDATE_JUST_CURSOR);
+		window->new_scrolled_lines = 0;
+		if (window->hold_mode)
+			hold_mode(window, ON, 1);
+		else
+			hold_mode(window, OFF, 0);
 	}
 }
