@@ -1414,7 +1414,7 @@ char	*arg1,
 
 	if ((server = from_server) == -1)
 		server = primary_server;
-	if ((server != -1) && ((des = server_list[server].write) != -1))
+	if (server != -1 && ((des = server_list[server].write) != -1))
 	{
 		sprintf(buf, format, arg1, arg2, arg3, arg4, arg5,
 		    arg6, arg7, arg8, arg9, arg10);
