@@ -1090,16 +1090,16 @@ void	add_to_whois_queue(nick, func, format, arg1, arg2,
 void	(*func) ();
 char	*format,
 	*nick;
-int	arg1,
-	arg2,
-	arg3,
-	arg4,
-	arg5,
-	arg6,
-	arg7,
-	arg8,
-	arg9,
-	arg10;
+char	*arg1,
+	*arg2,
+	*arg3,
+	*arg4,
+	*arg5,
+	*arg6,
+	*arg7,
+	*arg8,
+	*arg9,
+	*arg10;
 {
 	int	Type;
 
